# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergySavingsChild(Model):
    """EnergySavingsChild.

    :param energy_savings: The energy savings amount
    :type energy_savings: float
    :param energy_savings_unit:
    :type energy_savings_unit: ~energycap.sdk.models.EnergySavingsUnit
    """

    _attribute_map = {
        'energy_savings': {'key': 'energySavings', 'type': 'float'},
        'energy_savings_unit': {'key': 'energySavingsUnit', 'type': 'EnergySavingsUnit'},
    }

    def __init__(self, **kwargs):
        super(EnergySavingsChild, self).__init__(**kwargs)
        self.energy_savings = kwargs.get('energy_savings', None)
        self.energy_savings_unit = kwargs.get('energy_savings_unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSubmissionPlaceChild(Model):
    """EnergyStarSubmissionPlaceChild.

    All required parameters must be populated in order to send to Azure.

    :param place_id: Required. The place identifier <span
     class='property-internal'>Required</span>
    :type place_id: int
    :param submission_periods: Required. The list of submission periods to
     include in the submission <span class='property-internal'>Required</span>
     <span class='property-internal'>Cannot be Empty</span>
    :type submission_periods: list[int]
    """

    _validation = {
        'place_id': {'required': True},
        'submission_periods': {'required': True},
    }

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'submission_periods': {'key': 'submissionPeriods', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarSubmissionPlaceChild, self).__init__(**kwargs)
        self.place_id = kwargs.get('place_id', None)
        self.submission_periods = kwargs.get('submission_periods', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ContactChild(Model):
    """ContactChild.

    :param contact_id: The contact identifier
    :type contact_id: int
    :param first: The contact's first name
    :type first: str
    :param middle: The contact's middle name
    :type middle: str
    :param last: The contact's last name
    :type last: str
    """

    _attribute_map = {
        'contact_id': {'key': 'contactId', 'type': 'int'},
        'first': {'key': 'first', 'type': 'str'},
        'middle': {'key': 'middle', 'type': 'str'},
        'last': {'key': 'last', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(ContactChild, self).__init__(**kwargs)
        self.contact_id = kwargs.get('contact_id', None)
        self.first = kwargs.get('first', None)
        self.middle = kwargs.get('middle', None)
        self.last = kwargs.get('last', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FlagStatusChild(Model):
    """FlagStatusChild.

    :param flag_status_id: The flag status identifier
    :type flag_status_id: int
    :param flag_status_info: Flag status information
    :type flag_status_info: str
    """

    _attribute_map = {
        'flag_status_id': {'key': 'flagStatusId', 'type': 'int'},
        'flag_status_info': {'key': 'flagStatusInfo', 'type': 'str'},
    }

    def __init__(self, *, flag_status_id: int=None, flag_status_info: str=None, **kwargs) -> None:
        super(FlagStatusChild, self).__init__(**kwargs)
        self.flag_status_id = flag_status_id
        self.flag_status_info = flag_status_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TagChild(Model):
    """TagChild.

    :param tag_type_id:
    :type tag_type_id: int
    :param tag_type_info:
    :type tag_type_info: str
    :param values:
    :type values: list[str]
    """

    _attribute_map = {
        'tag_type_id': {'key': 'tagTypeId', 'type': 'int'},
        'tag_type_info': {'key': 'tagTypeInfo', 'type': 'str'},
        'values': {'key': 'values', 'type': '[str]'},
    }

    def __init__(self, *, tag_type_id: int=None, tag_type_info: str=None, values=None, **kwargs) -> None:
        super(TagChild, self).__init__(**kwargs)
        self.tag_type_id = tag_type_id
        self.tag_type_info = tag_type_info
        self.values = values



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ApiUser(Model):
    """ApiUser.

    :param user_name:
    :type user_name: str
    :param full_name:
    :type full_name: str
    """

    _attribute_map = {
        'user_name': {'key': 'userName', 'type': 'str'},
        'full_name': {'key': 'fullName', 'type': 'str'},
    }

    def __init__(self, *, user_name: str=None, full_name: str=None, **kwargs) -> None:
        super(ApiUser, self).__init__(**kwargs)
        self.user_name = user_name
        self.full_name = full_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ShareResponse(Model):
    """ShareResponse.

    :param shared_with_everyone: True if the item is shared with everyone
    :type shared_with_everyone: bool
    :param shared_users: The list of individual users an item has been
     assigned to be shared with
     This does NOT take into account users that are in a shared user group
    :type shared_users: list[~energycap.sdk.models.UserChild]
    :param shared_user_groups: The list of user groups an item has been
     assigned to be shared with
    :type shared_user_groups: list[~energycap.sdk.models.UserGroupChild]
    """

    _attribute_map = {
        'shared_with_everyone': {'key': 'sharedWithEveryone', 'type': 'bool'},
        'shared_users': {'key': 'sharedUsers', 'type': '[UserChild]'},
        'shared_user_groups': {'key': 'sharedUserGroups', 'type': '[UserGroupChild]'},
    }

    def __init__(self, *, shared_with_everyone: bool=None, shared_users=None, shared_user_groups=None, **kwargs) -> None:
        super(ShareResponse, self).__init__(**kwargs)
        self.shared_with_everyone = shared_with_everyone
        self.shared_users = shared_users
        self.shared_user_groups = shared_user_groups



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountConnectionStatusResponse(Model):
    """AccountConnectionStatusResponse.

    :param connectable: When true this database is connectable to Portfolio
     Manager
    :type connectable: bool
    :param other_database_registered: Whether some other database is
     registered to portfolio manager or not
    :type other_database_registered: bool
    """

    _attribute_map = {
        'connectable': {'key': 'connectable', 'type': 'bool'},
        'other_database_registered': {'key': 'otherDatabaseRegistered', 'type': 'bool'},
    }

    def __init__(self, *, connectable: bool=None, other_database_registered: bool=None, **kwargs) -> None:
        super(AccountConnectionStatusResponse, self).__init__(**kwargs)
        self.connectable = connectable
        self.other_database_registered = other_database_registered



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccrualSettingsResponse(Model):
    """AccrualSettingsResponse.

    :param accrual_method: Accrual method to employ. Valid values are:
     simple      - cost per day from the most recent bill
     use history - unit cost based on historical bills
     (if AUC safety net used, use the most recent bill if the unit cost is
     within the safety net percentage,
     otherwise use a historical average of the last three years from the same
     period),
     or average cost per day if no usage
    :type accrual_method: str
    :param auc_safety_net: Use an average unit cost safety net (apply to most
     recent bill unit cost)
    :type auc_safety_net: bool
    :param auc_safety_net_percentage: Average unit cost safety net percentage
    :type auc_safety_net_percentage: int
    :param accrual_bill_filter: Default filter to use when selecting most
     recent bills. Valid value are:
     non-void       - select any non-void bill
     approved       - select only approved bills
     apexported     - select AP exported bills
     non-exporthold - select bills not held from AP export
    :type accrual_bill_filter: str
    """

    _attribute_map = {
        'accrual_method': {'key': 'accrualMethod', 'type': 'str'},
        'auc_safety_net': {'key': 'aucSafetyNet', 'type': 'bool'},
        'auc_safety_net_percentage': {'key': 'aucSafetyNetPercentage', 'type': 'int'},
        'accrual_bill_filter': {'key': 'accrualBillFilter', 'type': 'str'},
    }

    def __init__(self, *, accrual_method: str=None, auc_safety_net: bool=None, auc_safety_net_percentage: int=None, accrual_bill_filter: str=None, **kwargs) -> None:
        super(AccrualSettingsResponse, self).__init__(**kwargs)
        self.accrual_method = accrual_method
        self.auc_safety_net = auc_safety_net
        self.auc_safety_net_percentage = auc_safety_net_percentage
        self.accrual_bill_filter = accrual_bill_filter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarMeterLinkChild(Model):
    """EnergyStarMeterLinkChild.

    :param meter:
    :type meter: ~energycap.sdk.models.MeterChild
    :param pm_meter_id: The Portfolio Manager meter identifier
    :type pm_meter_id: long
    :param use_per_day: The meter's average use per day
    :type use_per_day: float
    :param use_unit:
    :type use_unit: ~energycap.sdk.models.UnitChild
    :param cost_per_day: The meter's average cost per day
    :type cost_per_day: float
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param energy_star_compatible: Is this meter's commodity ENERGY
     STAR-compatible?
    :type energy_star_compatible: bool
    """

    _attribute_map = {
        'meter': {'key': 'meter', 'type': 'MeterChild'},
        'pm_meter_id': {'key': 'pmMeterId', 'type': 'long'},
        'use_per_day': {'key': 'usePerDay', 'type': 'float'},
        'use_unit': {'key': 'useUnit', 'type': 'UnitChild'},
        'cost_per_day': {'key': 'costPerDay', 'type': 'float'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'energy_star_compatible': {'key': 'energyStarCompatible', 'type': 'bool'},
    }

    def __init__(self, *, meter=None, pm_meter_id: int=None, use_per_day: float=None, use_unit=None, cost_per_day: float=None, cost_unit=None, energy_star_compatible: bool=None, **kwargs) -> None:
        super(EnergyStarMeterLinkChild, self).__init__(**kwargs)
        self.meter = meter
        self.pm_meter_id = pm_meter_id
        self.use_per_day = use_per_day
        self.use_unit = use_unit
        self.cost_per_day = cost_per_day
        self.cost_unit = cost_unit
        self.energy_star_compatible = energy_star_compatible



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkCategoryResponse(Model):
    """BenchmarkCategoryResponse.

    :param benchmark_category_id: Benchmark Category Id
    :type benchmark_category_id: int
    :param benchmark_category_info: Benchmark Category Info
    :type benchmark_category_info: str
    """

    _attribute_map = {
        'benchmark_category_id': {'key': 'benchmarkCategoryId', 'type': 'int'},
        'benchmark_category_info': {'key': 'benchmarkCategoryInfo', 'type': 'str'},
    }

    def __init__(self, *, benchmark_category_id: int=None, benchmark_category_info: str=None, **kwargs) -> None:
        super(BenchmarkCategoryResponse, self).__init__(**kwargs)
        self.benchmark_category_id = benchmark_category_id
        self.benchmark_category_info = benchmark_category_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChannelResponse(Model):
    """ChannelResponse.

    :param channel_id: The channel identifier
    :type channel_id: int
    :param interval_minutes: The interval of the channel. The interval is
     measured in minutes
    :type interval_minutes: int
    :param observation_type:
    :type observation_type: ~energycap.sdk.models.ObservationTypeChild
    :param channel_description: Description of the channel
    :type channel_description: str
    :param channel_import_id: The import identifier for the channel.
    :type channel_import_id: str
    :param has_readings: Indicates if the channel has readings
    :type has_readings: bool
    :param first_reading_date: Date of the earliest reading for the channel
    :type first_reading_date: datetime
    :param last_reading_date: Date of the most recent reading for the channel
    :type last_reading_date: datetime
    :param channel_versions: List of channel versions
     Versions include channel settings that may change over time
    :type channel_versions: list[~energycap.sdk.models.ChannelVersionResponse]
    :param is_used_on_distribution: Indicates if the channel is a part of a
     distribution
    :type is_used_on_distribution: bool
    :param meter:
    :type meter: ~energycap.sdk.models.MeterChildIncludeMeterImportIdAndRoute
    """

    _attribute_map = {
        'channel_id': {'key': 'channelId', 'type': 'int'},
        'interval_minutes': {'key': 'intervalMinutes', 'type': 'int'},
        'observation_type': {'key': 'observationType', 'type': 'ObservationTypeChild'},
        'channel_description': {'key': 'channelDescription', 'type': 'str'},
        'channel_import_id': {'key': 'channelImportId', 'type': 'str'},
        'has_readings': {'key': 'hasReadings', 'type': 'bool'},
        'first_reading_date': {'key': 'firstReadingDate', 'type': 'iso-8601'},
        'last_reading_date': {'key': 'lastReadingDate', 'type': 'iso-8601'},
        'channel_versions': {'key': 'channelVersions', 'type': '[ChannelVersionResponse]'},
        'is_used_on_distribution': {'key': 'isUsedOnDistribution', 'type': 'bool'},
        'meter': {'key': 'meter', 'type': 'MeterChildIncludeMeterImportIdAndRoute'},
    }

    def __init__(self, *, channel_id: int=None, interval_minutes: int=None, observation_type=None, channel_description: str=None, channel_import_id: str=None, has_readings: bool=None, first_reading_date=None, last_reading_date=None, channel_versions=None, is_used_on_distribution: bool=None, meter=None, **kwargs) -> None:
        super(ChannelResponse, self).__init__(**kwargs)
        self.channel_id = channel_id
        self.interval_minutes = interval_minutes
        self.observation_type = observation_type
        self.channel_description = channel_description
        self.channel_import_id = channel_import_id
        self.has_readings = has_readings
        self.first_reading_date = first_reading_date
        self.last_reading_date = last_reading_date
        self.channel_versions = channel_versions
        self.is_used_on_distribution = is_used_on_distribution
        self.meter = meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestEnergyUseIntensity(Model):
    """PlaceDigestEnergyUseIntensity.

    :param period_name: The calendar period name
    :type period_name: str
    :param calendar_period: The calendar period number
    :type calendar_period: int
    :param calendar_year: The calendar year
    :type calendar_year: int
    :param use_per_area_trend: The running average use per area for the prior
     12 months
    :type use_per_area_trend: float
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param energy_projects: A list of energy projects for this building. To be
     listed, a project must end in this period.
     Projects are only displayed at the building level, but not at the
     organization level
    :type energy_projects:
     list[~energycap.sdk.models.PlaceDigestEnergyUseIntensityEuiEnergyProject]
    :param commodities: A breakdown of use per commodity
    :type commodities:
     list[~energycap.sdk.models.PlaceDigestEnergyUseIntensityEuiCommodity]
    """

    _attribute_map = {
        'period_name': {'key': 'periodName', 'type': 'str'},
        'calendar_period': {'key': 'calendarPeriod', 'type': 'int'},
        'calendar_year': {'key': 'calendarYear', 'type': 'int'},
        'use_per_area_trend': {'key': 'usePerAreaTrend', 'type': 'float'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'energy_projects': {'key': 'energyProjects', 'type': '[PlaceDigestEnergyUseIntensityEuiEnergyProject]'},
        'commodities': {'key': 'commodities', 'type': '[PlaceDigestEnergyUseIntensityEuiCommodity]'},
    }

    def __init__(self, *, period_name: str=None, calendar_period: int=None, calendar_year: int=None, use_per_area_trend: float=None, global_use_unit=None, energy_projects=None, commodities=None, **kwargs) -> None:
        super(PlaceDigestEnergyUseIntensity, self).__init__(**kwargs)
        self.period_name = period_name
        self.calendar_period = calendar_period
        self.calendar_year = calendar_year
        self.use_per_area_trend = use_per_area_trend
        self.global_use_unit = global_use_unit
        self.energy_projects = energy_projects
        self.commodities = commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FilterEdit(Model):
    """FilterEdit.

    All required parameters must be populated in order to send to Azure.

    :param field_id: Required. Data field ID for the filter <span
     class='property-internal'>Required</span>
    :type field_id: int
    :param operator: Required. Filter operator expressed as a string (e.g.
     "equals") <span class='property-internal'>Required</span>
    :type operator: str
    :param value: Filter value
    :type value: str
    """

    _validation = {
        'field_id': {'required': True},
        'operator': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'int'},
        'operator': {'key': 'operator', 'type': 'str'},
        'value': {'key': 'value', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(FilterEdit, self).__init__(**kwargs)
        self.field_id = kwargs.get('field_id', None)
        self.operator = kwargs.get('operator', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FloorAreaSplit(Model):
    """FloorAreaSplit.

    All required parameters must be populated in order to send to Azure.

    :param destination_account_id: Required. Destination account ID
     There must be an existing relationship between the DestinationAccountId
     and DestinationMeterId <span class='property-internal'>Required</span>
     <span class='property-internal'>Topmost (CostCenter)</span>
    :type destination_account_id: int
    :param destination_meter_id: Required. Destination meter ID
     There must be an existing relationship between the DestinationAccountId
     and DestinationMeterId <span class='property-internal'>Required</span>
     <span class='property-internal'>Topmost (LogicalDevice)</span>
    :type destination_meter_id: int
    :param weighting_factor: Required. Weighting factor to apply in floor area
     bill split for this account and meter <span class='property-info'>Max
     scale of 8</span> <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and
     1.7976931348623157E+308</span>
    :type weighting_factor: float
    """

    _validation = {
        'destination_account_id': {'required': True},
        'destination_meter_id': {'required': True},
        'weighting_factor': {'required': True, 'minimum': 0},
    }

    _attribute_map = {
        'destination_account_id': {'key': 'destinationAccountId', 'type': 'int'},
        'destination_meter_id': {'key': 'destinationMeterId', 'type': 'int'},
        'weighting_factor': {'key': 'weightingFactor', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(FloorAreaSplit, self).__init__(**kwargs)
        self.destination_account_id = kwargs.get('destination_account_id', None)
        self.destination_meter_id = kwargs.get('destination_meter_id', None)
        self.weighting_factor = kwargs.get('weighting_factor', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ChargebackWorkflowBase(Model):
    """ChargebackWorkflowBase.

    :param chargeback_workflow_id: Identifier for the chargeback workflow
    :type chargeback_workflow_id: int
    :param chargeback_workflow_info: Name given to the chargeback workflow
    :type chargeback_workflow_info: str
    """

    _attribute_map = {
        'chargeback_workflow_id': {'key': 'chargebackWorkflowId', 'type': 'int'},
        'chargeback_workflow_info': {'key': 'chargebackWorkflowInfo', 'type': 'str'},
    }

    def __init__(self, *, chargeback_workflow_id: int=None, chargeback_workflow_info: str=None, **kwargs) -> None:
        super(ChargebackWorkflowBase, self).__init__(**kwargs)
        self.chargeback_workflow_id = chargeback_workflow_id
        self.chargeback_workflow_info = chargeback_workflow_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalculatedBillCostResponse(Model):
    """Definition of how a calculated bill will get its cost.

    :param rate_schedule:
    :type rate_schedule: ~energycap.sdk.models.RateChildResponse
    :param fixed_unit_cost:
    :type fixed_unit_cost: ~energycap.sdk.models.FixedAmountResponse
    :param unit_cost_from_meter:
    :type unit_cost_from_meter: ~energycap.sdk.models.MeterChild
    :param fixed_amount: Use a fixed amount for bill cost
    :type fixed_amount: float
    :param copy_cost_from_meter:
    :type copy_cost_from_meter: ~energycap.sdk.models.CopyFromMeterResponse
    :param cost_calculation:
    :type cost_calculation: ~energycap.sdk.models.CalculationResponse
    :param calendarized_cost_calculation:
    :type calendarized_cost_calculation:
     ~energycap.sdk.models.CalendarizedCalculationResponse
    """

    _attribute_map = {
        'rate_schedule': {'key': 'rateSchedule', 'type': 'RateChildResponse'},
        'fixed_unit_cost': {'key': 'fixedUnitCost', 'type': 'FixedAmountResponse'},
        'unit_cost_from_meter': {'key': 'unitCostFromMeter', 'type': 'MeterChild'},
        'fixed_amount': {'key': 'fixedAmount', 'type': 'float'},
        'copy_cost_from_meter': {'key': 'copyCostFromMeter', 'type': 'CopyFromMeterResponse'},
        'cost_calculation': {'key': 'costCalculation', 'type': 'CalculationResponse'},
        'calendarized_cost_calculation': {'key': 'calendarizedCostCalculation', 'type': 'CalendarizedCalculationResponse'},
    }

    def __init__(self, **kwargs):
        super(CalculatedBillCostResponse, self).__init__(**kwargs)
        self.rate_schedule = kwargs.get('rate_schedule', None)
        self.fixed_unit_cost = kwargs.get('fixed_unit_cost', None)
        self.unit_cost_from_meter = kwargs.get('unit_cost_from_meter', None)
        self.fixed_amount = kwargs.get('fixed_amount', None)
        self.copy_cost_from_meter = kwargs.get('copy_cost_from_meter', None)
        self.cost_calculation = kwargs.get('cost_calculation', None)
        self.calendarized_cost_calculation = kwargs.get('calendarized_cost_calculation', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillActionMoveList(Model):
    """BillActionMoveList.

    :param account_id: Destination Account Id <span
     class='property-internal'>Required (defined)</span>
    :type account_id: int
    :param account_meter_ids: Destination AccountMeter Ids <span
     class='property-internal'>Required (defined)</span>
    :type account_meter_ids: list[int]
    :param update_account_gls: Use Account General Ledger from destination
     account? <span class='property-internal'>Required (defined)</span>
    :type update_account_gls: bool
    :param update_meter_gls: Use Meter General Ledger from destination meter?
     <span class='property-internal'>Required (defined)</span>
    :type update_meter_gls: bool
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_meter_ids': {'key': 'accountMeterIds', 'type': '[int]'},
        'update_account_gls': {'key': 'updateAccountGLs', 'type': 'bool'},
        'update_meter_gls': {'key': 'updateMeterGLs', 'type': 'bool'},
    }

    def __init__(self, *, account_id: int=None, account_meter_ids=None, update_account_gls: bool=None, update_meter_gls: bool=None, **kwargs) -> None:
        super(BillActionMoveList, self).__init__(**kwargs)
        self.account_id = account_id
        self.account_meter_ids = account_meter_ids
        self.update_account_gls = update_account_gls
        self.update_meter_gls = update_meter_gls



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationSettingsResponse(Model):
    """NotificationSettingsResponse.

    :param allow_users_to_email_notifications: Are user's allowed to get email
     notifications
    :type allow_users_to_email_notifications: bool
    :param notification_settings: The list of notification settings available
     and their configured value
    :type notification_settings:
     list[~energycap.sdk.models.NotificationSettingResponse]
    """

    _attribute_map = {
        'allow_users_to_email_notifications': {'key': 'allowUsersToEmailNotifications', 'type': 'bool'},
        'notification_settings': {'key': 'notificationSettings', 'type': '[NotificationSettingResponse]'},
    }

    def __init__(self, **kwargs):
        super(NotificationSettingsResponse, self).__init__(**kwargs)
        self.allow_users_to_email_notifications = kwargs.get('allow_users_to_email_notifications', None)
        self.notification_settings = kwargs.get('notification_settings', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceGroupCategoryChild(Model):
    """PlaceGroupCategoryChild.

    :param place_group_category_id:
    :type place_group_category_id: int
    :param place_group_category_code:
    :type place_group_category_code: str
    :param place_group_category_info:
    :type place_group_category_info: str
    """

    _attribute_map = {
        'place_group_category_id': {'key': 'placeGroupCategoryId', 'type': 'int'},
        'place_group_category_code': {'key': 'placeGroupCategoryCode', 'type': 'str'},
        'place_group_category_info': {'key': 'placeGroupCategoryInfo', 'type': 'str'},
    }

    def __init__(self, *, place_group_category_id: int=None, place_group_category_code: str=None, place_group_category_info: str=None, **kwargs) -> None:
        super(PlaceGroupCategoryChild, self).__init__(**kwargs)
        self.place_group_category_id = place_group_category_id
        self.place_group_category_code = place_group_category_code
        self.place_group_category_info = place_group_category_info



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TopmostPlace(Model):
    """TopmostPlace.

    :param is_multi_topmost_place: User's topmost combines multiple places
    :type is_multi_topmost_place: bool
    :param multi_topmost_places:
    :type multi_topmost_places: list[~energycap.sdk.models.PlaceChild]
    :param place_id: The place identifier
    :type place_id: int
    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_type:
    :type place_type: ~energycap.sdk.models.PlaceTypeResponse
    """

    _attribute_map = {
        'is_multi_topmost_place': {'key': 'isMultiTopmostPlace', 'type': 'bool'},
        'multi_topmost_places': {'key': 'multiTopmostPlaces', 'type': '[PlaceChild]'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_type': {'key': 'placeType', 'type': 'PlaceTypeResponse'},
    }

    def __init__(self, *, is_multi_topmost_place: bool=None, multi_topmost_places=None, place_id: int=None, place_code: str=None, place_info: str=None, place_type=None, **kwargs) -> None:
        super(TopmostPlace, self).__init__(**kwargs)
        self.is_multi_topmost_place = is_multi_topmost_place
        self.multi_topmost_places = multi_topmost_places
        self.place_id = place_id
        self.place_code = place_code
        self.place_info = place_info
        self.place_type = place_type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportGroupResponse(Model):
    """ReportGroupResponse.

    :param report_group_id:
    :type report_group_id: int
    :param report_group_code:
    :type report_group_code: str
    :param report_group_info:
    :type report_group_info: str
    :param reports:
    :type reports: list[~energycap.sdk.models.ReportChild]
    """

    _attribute_map = {
        'report_group_id': {'key': 'reportGroupId', 'type': 'int'},
        'report_group_code': {'key': 'reportGroupCode', 'type': 'str'},
        'report_group_info': {'key': 'reportGroupInfo', 'type': 'str'},
        'reports': {'key': 'reports', 'type': '[ReportChild]'},
    }

    def __init__(self, **kwargs):
        super(ReportGroupResponse, self).__init__(**kwargs)
        self.report_group_id = kwargs.get('report_group_id', None)
        self.report_group_code = kwargs.get('report_group_code', None)
        self.report_group_info = kwargs.get('report_group_info', None)
        self.reports = kwargs.get('reports', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TemplateVendorLineRequest(Model):
    """TemplateVendorLineRequest.

    All required parameters must be populated in order to send to Azure.

    :param observation_type_id: Required. Specifies the type of line to create
     Only cost observation types are allowed
     To get the valid list of observation type ids call the GetObservationTypes
     API with ?filter=nounId one of '4'|'6'|'23' <span
     class='property-internal'>Required</span>
    :type observation_type_id: int
    :param caption: Required. The label for this line, that will be shown on
     the bill <span class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type caption: str
    """

    _validation = {
        'observation_type_id': {'required': True},
        'caption': {'required': True, 'max_length': 32, 'min_length': 0},
    }

    _attribute_map = {
        'observation_type_id': {'key': 'observationTypeId', 'type': 'int'},
        'caption': {'key': 'caption', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TemplateVendorLineRequest, self).__init__(**kwargs)
        self.observation_type_id = kwargs.get('observation_type_id', None)
        self.caption = kwargs.get('caption', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillEntryBodyLineChild(Model):
    """BillEntryBodyLineChild.

    :param value: The body line's numeric value
    :type value: float
    :param type: The body line's observation type
    :type type: str
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'value': {'key': 'value', 'type': 'float'},
        'type': {'key': 'type', 'type': 'str'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(BillEntryBodyLineChild, self).__init__(**kwargs)
        self.value = kwargs.get('value', None)
        self.type = kwargs.get('type', None)
        self.unit = kwargs.get('unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceSubmissionStatusResponse(Model):
    """EnergyStarPlaceSubmissionStatusResponse.

    :param place_id: The place identifier
    :type place_id: int
    :param place_info: The place name
    :type place_info: str
    :param place_code: The place code
    :type place_code: str
    :param place_submission_type:
    :type place_submission_type: ~energycap.sdk.models.SubmissionTypeResponse
    :param place_size:
    :type place_size: ~energycap.sdk.models.PlaceSizeChild
    :param place_submission_status: The list of submission periods and the
     submission status for each period
    :type place_submission_status:
     list[~energycap.sdk.models.EnergyStarPlaceSubmissionStatusChild]
    """

    _attribute_map = {
        'place_id': {'key': 'placeId', 'type': 'int'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_submission_type': {'key': 'placeSubmissionType', 'type': 'SubmissionTypeResponse'},
        'place_size': {'key': 'placeSize', 'type': 'PlaceSizeChild'},
        'place_submission_status': {'key': 'placeSubmissionStatus', 'type': '[EnergyStarPlaceSubmissionStatusChild]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceSubmissionStatusResponse, self).__init__(**kwargs)
        self.place_id = kwargs.get('place_id', None)
        self.place_info = kwargs.get('place_info', None)
        self.place_code = kwargs.get('place_code', None)
        self.place_submission_type = kwargs.get('place_submission_type', None)
        self.place_size = kwargs.get('place_size', None)
        self.place_submission_status = kwargs.get('place_submission_status', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillAccountMeterChild(Model):
    """BillAccountMeterChild.

    :param account_id: The bill-account-meter's account id
    :type account_id: int
    :param meter_id: The bill-account-meter's meter id
    :type meter_id: int
    :param native_use: The bill-account-meter's native use
    :type native_use: float
    :param native_use_unit:
    :type native_use_unit: ~energycap.sdk.models.UnitChild
    :param direct_cost: The bill-account-meter's direct cost
    :type direct_cost: float
    :param direct_cost_unit:
    :type direct_cost_unit: ~energycap.sdk.models.UnitChild
    :param native_use_unit_cost: The bill-account-meter's native use unit cost
    :type native_use_unit_cost: float
    :param native_use_per_day: The bill-account-meter's native use per day
    :type native_use_per_day: float
    :param direct_cost_per_day: The bill-account-meter's direct cost per day
    :type direct_cost_per_day: float
    :param native_billed_demand: The bill-account-meter's native billed demand
    :type native_billed_demand: float
    :param native_billed_demand_unit:
    :type native_billed_demand_unit: ~energycap.sdk.models.UnitChild
    :param native_actual_demand: The bill-account-meter's native actual demand
    :type native_actual_demand: float
    :param native_actual_demand_unit:
    :type native_actual_demand_unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'native_use': {'key': 'nativeUse', 'type': 'float'},
        'native_use_unit': {'key': 'nativeUseUnit', 'type': 'UnitChild'},
        'direct_cost': {'key': 'directCost', 'type': 'float'},
        'direct_cost_unit': {'key': 'directCostUnit', 'type': 'UnitChild'},
        'native_use_unit_cost': {'key': 'nativeUseUnitCost', 'type': 'float'},
        'native_use_per_day': {'key': 'nativeUsePerDay', 'type': 'float'},
        'direct_cost_per_day': {'key': 'directCostPerDay', 'type': 'float'},
        'native_billed_demand': {'key': 'nativeBilledDemand', 'type': 'float'},
        'native_billed_demand_unit': {'key': 'nativeBilledDemandUnit', 'type': 'UnitChild'},
        'native_actual_demand': {'key': 'nativeActualDemand', 'type': 'float'},
        'native_actual_demand_unit': {'key': 'nativeActualDemandUnit', 'type': 'UnitChild'},
    }

    def __init__(self, **kwargs):
        super(BillAccountMeterChild, self).__init__(**kwargs)
        self.account_id = kwargs.get('account_id', None)
        self.meter_id = kwargs.get('meter_id', None)
        self.native_use = kwargs.get('native_use', None)
        self.native_use_unit = kwargs.get('native_use_unit', None)
        self.direct_cost = kwargs.get('direct_cost', None)
        self.direct_cost_unit = kwargs.get('direct_cost_unit', None)
        self.native_use_unit_cost = kwargs.get('native_use_unit_cost', None)
        self.native_use_per_day = kwargs.get('native_use_per_day', None)
        self.direct_cost_per_day = kwargs.get('direct_cost_per_day', None)
        self.native_billed_demand = kwargs.get('native_billed_demand', None)
        self.native_billed_demand_unit = kwargs.get('native_billed_demand_unit', None)
        self.native_actual_demand = kwargs.get('native_actual_demand', None)
        self.native_actual_demand_unit = kwargs.get('native_actual_demand_unit', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GroupDisplaySetting(Model):
    """Display settings for the user when viewing benchmark charts.

    :param period_type: Date period type
     Possible value include 1 (Last Twelve Months), 2 (Last Calendar Year), 3
     (Last Fiscal Year), 4 (User Defined Range) <span
     class='property-internal'>One of 1, 2, 3, 4 </span>
    :type period_type: int
    :param user_defined_range_start_period: Benchmark Chart Start Period when
     using Period Type 4 (User Defined Range)
     Will return null for all other period types <span
     class='property-internal'>Required when PeriodType is set to 4</span>
    :type user_defined_range_start_period: int
    :param user_defined_range_end_period: Benchmark Chart End Period when
     using Period Type 4 (User Defined Range)
     Will return null for all other period types <span
     class='property-internal'>Required when PeriodType is set to 4</span>
    :type user_defined_range_end_period: int
    :param data_view: Data view (actual, calendarized, normalized) <span
     class='property-internal'>One of actual, calendarized, normalized </span>
    :type data_view: str
    :param commodity_id: Unique identifier of the commodity by which benchmark
     charts will be filtered
    :type commodity_id: int
    :param show_excluded_members: Indicates whether or not to show excluded
     group members
    :type show_excluded_members: bool
    :param show_zero_averages: Indicates whether or not to show zero averages
     in benchmark charts
    :type show_zero_averages: bool
    """

    _attribute_map = {
        'period_type': {'key': 'periodType', 'type': 'int'},
        'user_defined_range_start_period': {'key': 'userDefinedRangeStartPeriod', 'type': 'int'},
        'user_defined_range_end_period': {'key': 'userDefinedRangeEndPeriod', 'type': 'int'},
        'data_view': {'key': 'dataView', 'type': 'str'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'show_excluded_members': {'key': 'showExcludedMembers', 'type': 'bool'},
        'show_zero_averages': {'key': 'showZeroAverages', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(GroupDisplaySetting, self).__init__(**kwargs)
        self.period_type = kwargs.get('period_type', None)
        self.user_defined_range_start_period = kwargs.get('user_defined_range_start_period', None)
        self.user_defined_range_end_period = kwargs.get('user_defined_range_end_period', None)
        self.data_view = kwargs.get('data_view', None)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.show_excluded_members = kwargs.get('show_excluded_members', None)
        self.show_zero_averages = kwargs.get('show_zero_averages', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestSavingsYearlyResponse(Model):
    """PlaceDigestSavingsYearlyResponse.

    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_id: The place identifier
    :type place_id: int
    :param all_time_batcc_global_use: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Global Use
    :type all_time_batcc_global_use: float
    :param all_time_global_use: Program to Date Global Use
    :type all_time_global_use: float
    :param all_time_savings_global_use: Program to Date Savings Global Use =
     allTimeBATCCGlobalUse - allTimeGlobalUse
    :type all_time_savings_global_use: float
    :param all_time_batcc_total_cost: Program to Date BATCC (Baseline Adjusted
     to Current Conditions) Total Cost
    :type all_time_batcc_total_cost: float
    :param all_time_total_cost: Program to Date Savings Total Cost
    :type all_time_total_cost: float
    :param all_time_savings_total_cost: Program to Date Savings Total Cost =
     allTimeBATCCTotalCost - allTimeTotalCost
    :type all_time_savings_total_cost: float
    :param results: An array of savings yearly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestSavingsYearlyResponseResults]
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param commodities: An array of savings yearly data per commodity
    :type commodities:
     list[~energycap.sdk.models.PlaceDigestSavingsYearlyResponseCommodityData]
    """

    _attribute_map = {
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'all_time_batcc_global_use': {'key': 'allTimeBATCCGlobalUse', 'type': 'float'},
        'all_time_global_use': {'key': 'allTimeGlobalUse', 'type': 'float'},
        'all_time_savings_global_use': {'key': 'allTimeSavingsGlobalUse', 'type': 'float'},
        'all_time_batcc_total_cost': {'key': 'allTimeBATCCTotalCost', 'type': 'float'},
        'all_time_total_cost': {'key': 'allTimeTotalCost', 'type': 'float'},
        'all_time_savings_total_cost': {'key': 'allTimeSavingsTotalCost', 'type': 'float'},
        'results': {'key': 'results', 'type': '[PlaceDigestSavingsYearlyResponseResults]'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'commodities': {'key': 'commodities', 'type': '[PlaceDigestSavingsYearlyResponseCommodityData]'},
    }

    def __init__(self, **kwargs):
        super(PlaceDigestSavingsYearlyResponse, self).__init__(**kwargs)
        self.place_code = kwargs.get('place_code', None)
        self.place_info = kwargs.get('place_info', None)
        self.place_id = kwargs.get('place_id', None)
        self.all_time_batcc_global_use = kwargs.get('all_time_batcc_global_use', None)
        self.all_time_global_use = kwargs.get('all_time_global_use', None)
        self.all_time_savings_global_use = kwargs.get('all_time_savings_global_use', None)
        self.all_time_batcc_total_cost = kwargs.get('all_time_batcc_total_cost', None)
        self.all_time_total_cost = kwargs.get('all_time_total_cost', None)
        self.all_time_savings_total_cost = kwargs.get('all_time_savings_total_cost', None)
        self.results = kwargs.get('results', None)
        self.updated = kwargs.get('updated', None)
        self.global_use_unit = kwargs.get('global_use_unit', None)
        self.cost_unit = kwargs.get('cost_unit', None)
        self.commodities = kwargs.get('commodities', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionDetailsResponse(Model):
    """ReportDistributionDetailsResponse.

    :param report_distribution_id: The id of the report distribution
    :type report_distribution_id: int
    :param report_distribution_name: The name of the report distribution
    :type report_distribution_name: str
    :param created_by_user:
    :type created_by_user: ~energycap.sdk.models.UserChild
    :param created_date: The date and time the report distribution was created
    :type created_date: datetime
    :param modified_by_user:
    :type modified_by_user: ~energycap.sdk.models.UserChild
    :param modified_date: The date and time of the most recent modification
    :type modified_date: datetime
    :param last_run_date: Last time the report distribution was run
    :type last_run_date: datetime
    :param next_run_date: Next time the report distribution will run
    :type next_run_date: datetime
    :param enabled: Indicates if the report distribution is currently enabled
    :type enabled: bool
    :param specific_report_id: The id of the report being distributed
    :type specific_report_id: int
    :param base_report:
    :type base_report: ~energycap.sdk.models.ReportChild
    :param email_settings:
    :type email_settings:
     ~energycap.sdk.models.ReportDistributionEmailSettings
    """

    _attribute_map = {
        'report_distribution_id': {'key': 'reportDistributionId', 'type': 'int'},
        'report_distribution_name': {'key': 'reportDistributionName', 'type': 'str'},
        'created_by_user': {'key': 'createdByUser', 'type': 'UserChild'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'modified_by_user': {'key': 'modifiedByUser', 'type': 'UserChild'},
        'modified_date': {'key': 'modifiedDate', 'type': 'iso-8601'},
        'last_run_date': {'key': 'lastRunDate', 'type': 'iso-8601'},
        'next_run_date': {'key': 'nextRunDate', 'type': 'iso-8601'},
        'enabled': {'key': 'enabled', 'type': 'bool'},
        'specific_report_id': {'key': 'specificReportId', 'type': 'int'},
        'base_report': {'key': 'baseReport', 'type': 'ReportChild'},
        'email_settings': {'key': 'emailSettings', 'type': 'ReportDistributionEmailSettings'},
    }

    def __init__(self, *, report_distribution_id: int=None, report_distribution_name: str=None, created_by_user=None, created_date=None, modified_by_user=None, modified_date=None, last_run_date=None, next_run_date=None, enabled: bool=None, specific_report_id: int=None, base_report=None, email_settings=None, **kwargs) -> None:
        super(ReportDistributionDetailsResponse, self).__init__(**kwargs)
        self.report_distribution_id = report_distribution_id
        self.report_distribution_name = report_distribution_name
        self.created_by_user = created_by_user
        self.created_date = created_date
        self.modified_by_user = modified_by_user
        self.modified_date = modified_date
        self.last_run_date = last_run_date
        self.next_run_date = next_run_date
        self.enabled = enabled
        self.specific_report_id = specific_report_id
        self.base_report = base_report
        self.email_settings = email_settings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ProjectManagerResponse(Model):
    """ProjectManagerResponse.

    :param project_manager_full_name: The full name of project manager
    :type project_manager_full_name: str
    :param project_manager_code: The code for project manager
    :type project_manager_code: str
    """

    _attribute_map = {
        'project_manager_full_name': {'key': 'projectManagerFullName', 'type': 'str'},
        'project_manager_code': {'key': 'projectManagerCode', 'type': 'str'},
    }

    def __init__(self, *, project_manager_full_name: str=None, project_manager_code: str=None, **kwargs) -> None:
        super(ProjectManagerResponse, self).__init__(**kwargs)
        self.project_manager_full_name = project_manager_full_name
        self.project_manager_code = project_manager_code



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Reviewed(Model):
    """Reviewed.

    :param reviewed: Indicates whether or not the savings has been reviewed
    :type reviewed: bool
    :param reviewed_by:
    :type reviewed_by: ~energycap.sdk.models.UserChild
    :param reviewed_date: Reviewed date
    :type reviewed_date: datetime
    """

    _attribute_map = {
        'reviewed': {'key': 'reviewed', 'type': 'bool'},
        'reviewed_by': {'key': 'reviewedBy', 'type': 'UserChild'},
        'reviewed_date': {'key': 'reviewedDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(Reviewed, self).__init__(**kwargs)
        self.reviewed = kwargs.get('reviewed', None)
        self.reviewed_by = kwargs.get('reviewed_by', None)
        self.reviewed_date = kwargs.get('reviewed_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHeaderWorkflowChild(Model):
    """BillHeaderWorkflowChild.

    :param use_field:
    :type use_field: bool
    :param required:
    :type required: bool
    """

    _attribute_map = {
        'use_field': {'key': 'useField', 'type': 'bool'},
        'required': {'key': 'required', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(BillHeaderWorkflowChild, self).__init__(**kwargs)
        self.use_field = kwargs.get('use_field', None)
        self.required = kwargs.get('required', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserGroupChild(Model):
    """UserGroupChild.

    :param user_group_id: The user group identifier
    :type user_group_id: int
    :param user_group_name: The user group name
    :type user_group_name: str
    """

    _attribute_map = {
        'user_group_id': {'key': 'userGroupId', 'type': 'int'},
        'user_group_name': {'key': 'userGroupName', 'type': 'str'},
    }

    def __init__(self, *, user_group_id: int=None, user_group_name: str=None, **kwargs) -> None:
        super(UserGroupChild, self).__init__(**kwargs)
        self.user_group_id = user_group_id
        self.user_group_name = user_group_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationActionButtonResponse(Model):
    """NotificationActionButtonResponse.

    :param url: Url the action will link to
    :type url: str
    :param label: Label the action will display
    :type label: str
    :param open_in_new_window: Should clicking the action link open a new
     window
    :type open_in_new_window: bool
    """

    _attribute_map = {
        'url': {'key': 'url', 'type': 'str'},
        'label': {'key': 'label', 'type': 'str'},
        'open_in_new_window': {'key': 'openInNewWindow', 'type': 'bool'},
    }

    def __init__(self, *, url: str=None, label: str=None, open_in_new_window: bool=None, **kwargs) -> None:
        super(NotificationActionButtonResponse, self).__init__(**kwargs)
        self.url = url
        self.label = label
        self.open_in_new_window = open_in_new_window



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarCommodityMeterTypeMapping(Model):
    """EnergyStarCommodityMeterTypeMapping.

    :param submission_unit:
    :type submission_unit: ~energycap.sdk.models.UnitChild
    :param portfolio_manager_commodity_mapping:
    :type portfolio_manager_commodity_mapping:
     ~energycap.sdk.models.EnergyStarCommodityMeterTypeMappingChild
    :param commodity_id: The commodity identifier
    :type commodity_id: int
    :param commodity_code: The commodity code
    :type commodity_code: str
    :param commodity_info: The commodity info
    :type commodity_info: str
    """

    _attribute_map = {
        'submission_unit': {'key': 'submissionUnit', 'type': 'UnitChild'},
        'portfolio_manager_commodity_mapping': {'key': 'portfolioManagerCommodityMapping', 'type': 'EnergyStarCommodityMeterTypeMappingChild'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'commodity_code': {'key': 'commodityCode', 'type': 'str'},
        'commodity_info': {'key': 'commodityInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarCommodityMeterTypeMapping, self).__init__(**kwargs)
        self.submission_unit = kwargs.get('submission_unit', None)
        self.portfolio_manager_commodity_mapping = kwargs.get('portfolio_manager_commodity_mapping', None)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.commodity_code = kwargs.get('commodity_code', None)
        self.commodity_info = kwargs.get('commodity_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateVersionRequest(Model):
    """RateVersionRequest.

    All required parameters must be populated in order to send to Azure.

    :param effective_date: Required. Effective date for the version <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 12/31/1899 and 1/1/3000</span>
    :type effective_date: datetime
    :param note: Note for the version <span class='property-internal'>Must be
     between 0 and 255 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type note: str
    :param use_unit_cost: Unit cost for the use <span
     class='property-info'>Max scale of 8</span> <span
     class='property-info'>NULL Valid</span> <span
     class='property-internal'>Required (defined)</span>
    :type use_unit_cost: float
    :param use_unit_id: Use unit ID <span class='property-internal'>Required
     (defined)</span>
    :type use_unit_id: int
    :param demand_unit_cost: Unit cost for the demand <span
     class='property-info'>Max scale of 8</span> <span
     class='property-info'>NULL Valid</span> <span
     class='property-internal'>Required (defined)</span>
    :type demand_unit_cost: float
    :param demand_unit_id: Demand unit ID <span
     class='property-internal'>Required (defined)</span>
    :type demand_unit_id: int
    :param account_line_items: Cost bodylines for the account <span
     class='property-internal'>Required (defined)</span>
    :type account_line_items:
     list[~energycap.sdk.models.GenericBodylineRequest]
    :param meter_line_items: Cost bodylines for the meter <span
     class='property-internal'>Required (defined)</span>
    :type meter_line_items: list[~energycap.sdk.models.GenericBodylineRequest]
    :param udfs: List of user defined/custom fields and values for this
     version
     If the Udfs list is null or empty no values are assigned
     If a udf is omitted no value is assigned to that udf
     To remove a value from an existing Udf, pass in the UdfId and set the
     Value to null <span class='property-internal'>Required (defined)</span>
    :type udfs: list[~energycap.sdk.models.UDFValue]
    """

    _validation = {
        'effective_date': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'note': {'key': 'note', 'type': 'str'},
        'use_unit_cost': {'key': 'useUnitCost', 'type': 'float'},
        'use_unit_id': {'key': 'useUnitId', 'type': 'int'},
        'demand_unit_cost': {'key': 'demandUnitCost', 'type': 'float'},
        'demand_unit_id': {'key': 'demandUnitId', 'type': 'int'},
        'account_line_items': {'key': 'accountLineItems', 'type': '[GenericBodylineRequest]'},
        'meter_line_items': {'key': 'meterLineItems', 'type': '[GenericBodylineRequest]'},
        'udfs': {'key': 'udfs', 'type': '[UDFValue]'},
    }

    def __init__(self, **kwargs):
        super(RateVersionRequest, self).__init__(**kwargs)
        self.effective_date = kwargs.get('effective_date', None)
        self.note = kwargs.get('note', None)
        self.use_unit_cost = kwargs.get('use_unit_cost', None)
        self.use_unit_id = kwargs.get('use_unit_id', None)
        self.demand_unit_cost = kwargs.get('demand_unit_cost', None)
        self.demand_unit_id = kwargs.get('demand_unit_id', None)
        self.account_line_items = kwargs.get('account_line_items', None)
        self.meter_line_items = kwargs.get('meter_line_items', None)
        self.udfs = kwargs.get('udfs', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserRoleRequest(Model):
    """UserRoleRequest.

    :param user_role_id: The user role id to set for the user <span
     class='property-internal'>Required (defined)</span>
    :type user_role_id: int
    """

    _attribute_map = {
        'user_role_id': {'key': 'userRoleId', 'type': 'int'},
    }

    def __init__(self, *, user_role_id: int=None, **kwargs) -> None:
        super(UserRoleRequest, self).__init__(**kwargs)
        self.user_role_id = user_role_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RollupUnitUpdateCommonUnit(Model):
    """RollupUnitUpdateCommonUnit.

    :param commodity_id: The commodity identifier <span
     class='property-internal'>Required (defined)</span>
    :type commodity_id: int
    :param common_rollup_unit_id: The unit identifier that this commodity will
     roll up to <span class='property-internal'>Required (defined)</span>
    :type common_rollup_unit_id: int
    """

    _attribute_map = {
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'common_rollup_unit_id': {'key': 'commonRollupUnitId', 'type': 'int'},
    }

    def __init__(self, *, commodity_id: int=None, common_rollup_unit_id: int=None, **kwargs) -> None:
        super(RollupUnitUpdateCommonUnit, self).__init__(**kwargs)
        self.commodity_id = commodity_id
        self.common_rollup_unit_id = common_rollup_unit_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountChild(Model):
    """AccountChild.

    :param account_id:
    :type account_id: int
    :param account_code:
    :type account_code: str
    :param account_info:
    :type account_info: str
    :param vendor:
    :type vendor: ~energycap.sdk.models.VendorChild
    :param active:
    :type active: bool
    :param has_calculated_meter:
    :type has_calculated_meter: bool
    :param has_split_parent_meter:
    :type has_split_parent_meter: bool
    :param has_split_child_meter:
    :type has_split_child_meter: bool
    """

    _attribute_map = {
        'account_id': {'key': 'accountId', 'type': 'int'},
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'vendor': {'key': 'vendor', 'type': 'VendorChild'},
        'active': {'key': 'active', 'type': 'bool'},
        'has_calculated_meter': {'key': 'hasCalculatedMeter', 'type': 'bool'},
        'has_split_parent_meter': {'key': 'hasSplitParentMeter', 'type': 'bool'},
        'has_split_child_meter': {'key': 'hasSplitChildMeter', 'type': 'bool'},
    }

    def __init__(self, *, account_id: int=None, account_code: str=None, account_info: str=None, vendor=None, active: bool=None, has_calculated_meter: bool=None, has_split_parent_meter: bool=None, has_split_child_meter: bool=None, **kwargs) -> None:
        super(AccountChild, self).__init__(**kwargs)
        self.account_id = account_id
        self.account_code = account_code
        self.account_info = account_info
        self.vendor = vendor
        self.active = active
        self.has_calculated_meter = has_calculated_meter
        self.has_split_parent_meter = has_split_parent_meter
        self.has_split_child_meter = has_split_child_meter



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class FixedPercentage(Model):
    """FixedPercentage.

    All required parameters must be populated in order to send to Azure.

    :param destination_account_id: Required. Destination account ID <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (CostCenter)</span>
    :type destination_account_id: int
    :param destination_meter_id: Required. Destination meter ID
     The DestinationMeterId commodity must match the commodity <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (LogicalDevice)</span>
    :type destination_meter_id: int
    :param split_percentage: Required. Fixed percentage to apply in bill split
     for this account and meter
     Pass the percentage value
     For example 50.5% should be 50.5 <span class='property-info'>Max scale of
     8</span> <span class='property-internal'>Required</span>
    :type split_percentage: float
    """

    _validation = {
        'destination_account_id': {'required': True},
        'destination_meter_id': {'required': True},
        'split_percentage': {'required': True},
    }

    _attribute_map = {
        'destination_account_id': {'key': 'destinationAccountId', 'type': 'int'},
        'destination_meter_id': {'key': 'destinationMeterId', 'type': 'int'},
        'split_percentage': {'key': 'splitPercentage', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(FixedPercentage, self).__init__(**kwargs)
        self.destination_account_id = kwargs.get('destination_account_id', None)
        self.destination_meter_id = kwargs.get('destination_meter_id', None)
        self.split_percentage = kwargs.get('split_percentage', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarSettingsRequest(Model):
    """EnergyStarSettingsRequest.

    All required parameters must be populated in order to send to Azure.

    :param pm_user_name: The user name of the Portfolio Manager account to
     link. Not required if account already registered. <span
     class='property-internal'>Must be between 0 and 128 characters</span>
    :type pm_user_name: str
    :param earliest_submission_period: Required. The earliest period to submit
     <span class='property-internal'>Required</span>
    :type earliest_submission_period: int
    """

    _validation = {
        'pm_user_name': {'max_length': 128, 'min_length': 0},
        'earliest_submission_period': {'required': True},
    }

    _attribute_map = {
        'pm_user_name': {'key': 'pmUserName', 'type': 'str'},
        'earliest_submission_period': {'key': 'earliestSubmissionPeriod', 'type': 'int'},
    }

    def __init__(self, *, earliest_submission_period: int, pm_user_name: str=None, **kwargs) -> None:
        super(EnergyStarSettingsRequest, self).__init__(**kwargs)
        self.pm_user_name = pm_user_name
        self.earliest_submission_period = earliest_submission_period



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarPlaceLinkResponse(Model):
    """EnergyStarPlaceLinkResponse.

    :param place:
    :type place: ~energycap.sdk.models.PlaceChild
    :param pm_property_id: The Portfolio Manager property identifier
    :type pm_property_id: long
    :param meters: List of meters for this place
    :type meters: list[~energycap.sdk.models.EnergyStarMeterLinkChild]
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'PlaceChild'},
        'pm_property_id': {'key': 'pmPropertyId', 'type': 'long'},
        'meters': {'key': 'meters', 'type': '[EnergyStarMeterLinkChild]'},
    }

    def __init__(self, **kwargs):
        super(EnergyStarPlaceLinkResponse, self).__init__(**kwargs)
        self.place = kwargs.get('place', None)
        self.pm_property_id = kwargs.get('pm_property_id', None)
        self.meters = kwargs.get('meters', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecialAdjustmentEdit(Model):
    """SpecialAdjustmentEdit.

    All required parameters must be populated in order to send to Azure.

    :param special_adjustment_method_id: Required. The special adjustment
     method identifier <span class='property-internal'>Required</span>
    :type special_adjustment_method_id: int
    :param comments: Required. Reason for making the special adjustment <span
     class='property-internal'>Required</span>
    :type comments: str
    :param value: The amount
     See special adjustment method list for acceptable precision
     Precision of -1 means the value should not be passed in <span
     class='property-internal'>Required (defined)</span>
    :type value: float
    :param special_adjustment_type_id: Required. The special adjustment type
     identifier <span class='property-internal'>Required</span>
    :type special_adjustment_type_id: int
    :param start_date: Required. The start date <span
     class='property-internal'>Required</span>
    :type start_date: datetime
    :param end_date: Required. The end date <span
     class='property-internal'>Required</span>
    :type end_date: datetime
    :param annual_cycle_start_mmdd: The frequency start period
     Should only be passed when frequency type is Recurring <span
     class='property-internal'>Required (defined)</span>
    :type annual_cycle_start_mmdd: int
    :param annual_cycle_end_mmdd: The frequency end period
     Should only be passed when frequency type is Recurring <span
     class='property-internal'>Required (defined)</span>
    :type annual_cycle_end_mmdd: int
    """

    _validation = {
        'special_adjustment_method_id': {'required': True},
        'comments': {'required': True},
        'special_adjustment_type_id': {'required': True},
        'start_date': {'required': True},
        'end_date': {'required': True},
    }

    _attribute_map = {
        'special_adjustment_method_id': {'key': 'specialAdjustmentMethodId', 'type': 'int'},
        'comments': {'key': 'comments', 'type': 'str'},
        'value': {'key': 'value', 'type': 'float'},
        'special_adjustment_type_id': {'key': 'specialAdjustmentTypeId', 'type': 'int'},
        'start_date': {'key': 'startDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'annual_cycle_start_mmdd': {'key': 'annualCycleStartMMDD', 'type': 'int'},
        'annual_cycle_end_mmdd': {'key': 'annualCycleEndMMDD', 'type': 'int'},
    }

    def __init__(self, *, special_adjustment_method_id: int, comments: str, special_adjustment_type_id: int, start_date, end_date, value: float=None, annual_cycle_start_mmdd: int=None, annual_cycle_end_mmdd: int=None, **kwargs) -> None:
        super(SpecialAdjustmentEdit, self).__init__(**kwargs)
        self.special_adjustment_method_id = special_adjustment_method_id
        self.comments = comments
        self.value = value
        self.special_adjustment_type_id = special_adjustment_type_id
        self.start_date = start_date
        self.end_date = end_date
        self.annual_cycle_start_mmdd = annual_cycle_start_mmdd
        self.annual_cycle_end_mmdd = annual_cycle_end_mmdd



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class HierarchicalCostCenters2(Model):
    """HierarchicalCostCenters2.

    :param parent_id:
    :type parent_id: int
    :param cost_center_id:
    :type cost_center_id: int
    :param cost_center_info:
    :type cost_center_info: str
    :param cost_center_code:
    :type cost_center_code: str
    :param has_children:
    :type has_children: bool
    :param has_cost_center_children:
    :type has_cost_center_children: bool
    :param has_account_children:
    :type has_account_children: bool
    :param has_active_children:
    :type has_active_children: bool
    :param has_active_account_children:
    :type has_active_account_children: bool
    :param account_children:
    :type account_children: list[~energycap.sdk.models.CostCenterAccountChild]
    :param cost_center_children:
    :type cost_center_children:
     list[~energycap.sdk.models.HierarchicalCostCenters]
    """

    _attribute_map = {
        'parent_id': {'key': 'parentId', 'type': 'int'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'cost_center_info': {'key': 'costCenterInfo', 'type': 'str'},
        'cost_center_code': {'key': 'costCenterCode', 'type': 'str'},
        'has_children': {'key': 'hasChildren', 'type': 'bool'},
        'has_cost_center_children': {'key': 'hasCostCenterChildren', 'type': 'bool'},
        'has_account_children': {'key': 'hasAccountChildren', 'type': 'bool'},
        'has_active_children': {'key': 'hasActiveChildren', 'type': 'bool'},
        'has_active_account_children': {'key': 'hasActiveAccountChildren', 'type': 'bool'},
        'account_children': {'key': 'accountChildren', 'type': '[CostCenterAccountChild]'},
        'cost_center_children': {'key': 'costCenterChildren', 'type': '[HierarchicalCostCenters]'},
    }

    def __init__(self, **kwargs):
        super(HierarchicalCostCenters2, self).__init__(**kwargs)
        self.parent_id = kwargs.get('parent_id', None)
        self.cost_center_id = kwargs.get('cost_center_id', None)
        self.cost_center_info = kwargs.get('cost_center_info', None)
        self.cost_center_code = kwargs.get('cost_center_code', None)
        self.has_children = kwargs.get('has_children', None)
        self.has_cost_center_children = kwargs.get('has_cost_center_children', None)
        self.has_account_children = kwargs.get('has_account_children', None)
        self.has_active_children = kwargs.get('has_active_children', None)
        self.has_active_account_children = kwargs.get('has_active_account_children', None)
        self.account_children = kwargs.get('account_children', None)
        self.cost_center_children = kwargs.get('cost_center_children', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DistributionVersionManage(Model):
    """DistributionVersionManage.

    All required parameters must be populated in order to send to Azure.

    :param version_id: Version id to update
     VersionId must exist on the account and meter relationship being updated
     <span class='property-internal'>Required (defined)</span>
    :type version_id: int
    :param copy_version_id: An existing version id on this account meter to
     copy
     A new version will be created and all instructions will be copied to the
     new version
     CopyVersionId chargeback type must match the chargeback type being managed
     (Either "Split" or "Calculation").
     CopyVersionId must exist on the account and meter relationship being
     updated <span class='property-internal'>Required (defined)</span>
    :type copy_version_id: int
    :param name: Required. Name given to the version
     Name must be unique for a particular account and meter <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type name: str
    :param workflow_step_id: Workflow step this version will belong to
     The workflow step type must match the chargeback type being managed
     (Either "Split" or "Calculation") <span class='property-internal'>Required
     (defined)</span>
    :type workflow_step_id: int
    :param begin_period: Required. Begin period for the version in the format
     YYYYMM
     Cannot overlap any existing versions on this account and meter for the
     chargeback type being managed <span
     class='property-internal'>Required</span>
    :type begin_period: int
    :param end_period: End period for the version in the format YYYYMM
     null value means continuing indefinitely
     Cannot overlap any existing versions on this account and meter for the
     chargeback type being managed <span class='property-internal'>Required
     (defined)</span>
    :type end_period: int
    """

    _validation = {
        'name': {'required': True, 'max_length': 64, 'min_length': 0},
        'begin_period': {'required': True},
    }

    _attribute_map = {
        'version_id': {'key': 'versionId', 'type': 'int'},
        'copy_version_id': {'key': 'copyVersionId', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'workflow_step_id': {'key': 'workflowStepId', 'type': 'int'},
        'begin_period': {'key': 'beginPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
    }

    def __init__(self, **kwargs):
        super(DistributionVersionManage, self).__init__(**kwargs)
        self.version_id = kwargs.get('version_id', None)
        self.copy_version_id = kwargs.get('copy_version_id', None)
        self.name = kwargs.get('name', None)
        self.workflow_step_id = kwargs.get('workflow_step_id', None)
        self.begin_period = kwargs.get('begin_period', None)
        self.end_period = kwargs.get('end_period', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserGroupWithMembers(Model):
    """UserGroupWithMembers.

    :param members: List of user group members
    :type members: list[~energycap.sdk.models.UserChildWithEmail]
    :param user_group_id: The user group identifier
    :type user_group_id: int
    :param user_group_name: The user group name
    :type user_group_name: str
    """

    _attribute_map = {
        'members': {'key': 'members', 'type': '[UserChildWithEmail]'},
        'user_group_id': {'key': 'userGroupId', 'type': 'int'},
        'user_group_name': {'key': 'userGroupName', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(UserGroupWithMembers, self).__init__(**kwargs)
        self.members = kwargs.get('members', None)
        self.user_group_id = kwargs.get('user_group_id', None)
        self.user_group_name = kwargs.get('user_group_name', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReportDistributionLogReportSettings(Model):
    """ReportDistributionLogReportSettings.

    :param base_report:
    :type base_report: ~energycap.sdk.models.ReportChild
    :param report_filters: List of filters to apply to the report
    :type report_filters: list[~energycap.sdk.models.FilterResponse]
    """

    _attribute_map = {
        'base_report': {'key': 'baseReport', 'type': 'ReportChild'},
        'report_filters': {'key': 'reportFilters', 'type': '[FilterResponse]'},
    }

    def __init__(self, *, base_report=None, report_filters=None, **kwargs) -> None:
        super(ReportDistributionLogReportSettings, self).__init__(**kwargs)
        self.base_report = base_report
        self.report_filters = report_filters



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MeterGroupDigestChild(Model):
    """MeterGroupDigestChild.

    :param meter_id:
    :type meter_id: int
    :param meter_code:
    :type meter_code: str
    :param meter_info:
    :type meter_info: str
    :param meter_display:
    :type meter_display: str
    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param include_in_charts:
    :type include_in_charts: bool
    :param active: Indicates whether the Meter is Active
    :type active: bool
    :param is_calculated_meter: Indicates whether the Meter is a calculated
     meter
    :type is_calculated_meter: bool
    :param is_split_parent_meter: Indicates whether the Meter is a parent of a
     split
    :type is_split_parent_meter: bool
    :param is_split_child_meter: Indicates whether the Meter is a child of a
     split
    :type is_split_child_meter: bool
    """

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'meter_code': {'key': 'meterCode', 'type': 'str'},
        'meter_info': {'key': 'meterInfo', 'type': 'str'},
        'meter_display': {'key': 'meterDisplay', 'type': 'str'},
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'include_in_charts': {'key': 'includeInCharts', 'type': 'bool'},
        'active': {'key': 'active', 'type': 'bool'},
        'is_calculated_meter': {'key': 'isCalculatedMeter', 'type': 'bool'},
        'is_split_parent_meter': {'key': 'isSplitParentMeter', 'type': 'bool'},
        'is_split_child_meter': {'key': 'isSplitChildMeter', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(MeterGroupDigestChild, self).__init__(**kwargs)
        self.meter_id = kwargs.get('meter_id', None)
        self.meter_code = kwargs.get('meter_code', None)
        self.meter_info = kwargs.get('meter_info', None)
        self.meter_display = kwargs.get('meter_display', None)
        self.commodity = kwargs.get('commodity', None)
        self.include_in_charts = kwargs.get('include_in_charts', None)
        self.active = kwargs.get('active', None)
        self.is_calculated_meter = kwargs.get('is_calculated_meter', None)
        self.is_split_parent_meter = kwargs.get('is_split_parent_meter', None)
        self.is_split_child_meter = kwargs.get('is_split_child_meter', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DataAccessReleaseNoFileRequest(Model):
    """DataAccessReleaseNoFileRequest.

    All required parameters must be populated in order to send to Azure.

    :param account_number: Required. Account Number
     Should be a 12 digit number starting with 2. <span
     class='property-internal'>Required</span>
    :type account_number: str
    :param name_on_bill: Required.  <span
     class='property-internal'>Required</span>
    :type name_on_bill: str
    :param service_address: Required.  <span
     class='property-internal'>Required</span>
    :type service_address: str
    """

    _validation = {
        'account_number': {'required': True},
        'name_on_bill': {'required': True},
        'service_address': {'required': True},
    }

    _attribute_map = {
        'account_number': {'key': 'accountNumber', 'type': 'str'},
        'name_on_bill': {'key': 'nameOnBill', 'type': 'str'},
        'service_address': {'key': 'serviceAddress', 'type': 'str'},
    }

    def __init__(self, *, account_number: str, name_on_bill: str, service_address: str, **kwargs) -> None:
        super(DataAccessReleaseNoFileRequest, self).__init__(**kwargs)
        self.account_number = account_number
        self.name_on_bill = name_on_bill
        self.service_address = service_address



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class UserGroupResponse(Model):
    """UserGroupResponse.

    :param user_group_id: The user group identifier
    :type user_group_id: int
    :param user_group_name: The user group name
    :type user_group_name: str
    :param description: The user group description
    :type description: str
    :param member_count: The number of users in this group
    :type member_count: int
    :param last_updated: The last time a member was inserted, updated, or
     deleted from the group
    :type last_updated: datetime
    """

    _attribute_map = {
        'user_group_id': {'key': 'userGroupId', 'type': 'int'},
        'user_group_name': {'key': 'userGroupName', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'member_count': {'key': 'memberCount', 'type': 'int'},
        'last_updated': {'key': 'lastUpdated', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(UserGroupResponse, self).__init__(**kwargs)
        self.user_group_id = kwargs.get('user_group_id', None)
        self.user_group_name = kwargs.get('user_group_name', None)
        self.description = kwargs.get('description', None)
        self.member_count = kwargs.get('member_count', None)
        self.last_updated = kwargs.get('last_updated', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountEdit(Model):
    """AccountEdit.

    All required parameters must be populated in order to send to Azure.

    :param account_code: Required. The account code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type account_code: str
    :param account_info: Required. The account info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type account_info: str
    :param cost_center_id: Required. The identifier for the cost center to
     which the account belongs <span class='property-internal'>Topmost
     (CostCenter)</span> <span class='property-internal'>Required</span>
    :type cost_center_id: int
    :param customer_id: The identifier for the customer the account serves.
     This is normally only set for chargeback accounts <span
     class='property-internal'>Required (defined)</span>
    :type customer_id: int
    :param contact_id: The identifier for the account's contact <span
     class='property-internal'>Required (defined)</span>
    :type contact_id: int
    :param active: Indicates if the account is active or inactive <span
     class='property-internal'>Required (defined)</span>
    :type active: bool
    :param accrual_enabled: Indicates if the account is used with accruals
     <span class='property-internal'>Required (defined)</span>
    :type accrual_enabled: bool
    :param postal_code: The address postal code
     Required when country is US or CA <span class='property-internal'>Must be
     between 0 and 32 characters</span>
    :type postal_code: str
    :param city: The address city <span class='property-internal'>Must be
     between 0 and 100 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type city: str
    :param state: The address state <span class='property-internal'>Must be
     between 0 and 100 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type state: str
    :param country: Required. The address country <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 64 characters</span>
    :type country: str
    :param line1: The address first line <span class='property-internal'>Must
     be between 0 and 100 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type line1: str
    :param line2: The address second line <span class='property-internal'>Must
     be between 0 and 100 characters</span> <span
     class='property-internal'>Required (defined)</span>
    :type line2: str
    :param line3: The address third line <span class='property-internal'>Must
     be between 0 and 100 characters</span> <span
     class='property-internal'>Required (defined)</span>. Default value: "Æ" .
    :type line3: str
    :param deposit_paid: The date and time the account deposit was paid <span
     class='property-internal'>Required (defined)</span>
    :type deposit_paid: datetime
    :param deposit_return: The date and time the account deposit was returned
     <span class='property-internal'>Required (defined)</span>
    :type deposit_return: datetime
    :param deposit_note: A note related to the account deposit <span
     class='property-internal'>Required (defined)</span>
    :type deposit_note: str
    :param deposit_amount: The account deposit amount <span
     class='property-internal'>Required (defined)</span>
    :type deposit_amount: float
    :param memo: The account memo <span class='property-internal'>Required
     (defined)</span>
    :type memo: str
    :param service_start: The account's service begin date and time <span
     class='property-internal'>Required (defined)</span>
    :type service_start: datetime
    :param service_end: The account's service end date and time <span
     class='property-internal'>Required (defined)</span>
    :type service_end: datetime
    :param general_ledger_id: The identifier for the account's generalLedgerId
     <span class='property-internal'>Required (defined)</span>
    :type general_ledger_id: int
    :param account_description: A description of the account <span
     class='property-internal'>Must be between 0 and 4000 characters</span>
     <span class='property-internal'>Required (defined)</span>. Default value:
     "Æ" .
    :type account_description: str
    """

    _validation = {
        'account_code': {'required': True, 'max_length': 50, 'min_length': 0},
        'account_info': {'required': True, 'max_length': 50, 'min_length': 0},
        'cost_center_id': {'required': True},
        'postal_code': {'max_length': 32, 'min_length': 0},
        'city': {'max_length': 100, 'min_length': 0},
        'state': {'max_length': 100, 'min_length': 0},
        'country': {'required': True, 'max_length': 64, 'min_length': 0},
        'line1': {'max_length': 100, 'min_length': 0},
        'line2': {'max_length': 100, 'min_length': 0},
        'line3': {'max_length': 100, 'min_length': 0},
        'account_description': {'max_length': 4000, 'min_length': 0},
    }

    _attribute_map = {
        'account_code': {'key': 'accountCode', 'type': 'str'},
        'account_info': {'key': 'accountInfo', 'type': 'str'},
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'customer_id': {'key': 'customerId', 'type': 'int'},
        'contact_id': {'key': 'contactId', 'type': 'int'},
        'active': {'key': 'active', 'type': 'bool'},
        'accrual_enabled': {'key': 'accrualEnabled', 'type': 'bool'},
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'line1': {'key': 'line1', 'type': 'str'},
        'line2': {'key': 'line2', 'type': 'str'},
        'line3': {'key': 'line3', 'type': 'str'},
        'deposit_paid': {'key': 'depositPaid', 'type': 'iso-8601'},
        'deposit_return': {'key': 'depositReturn', 'type': 'iso-8601'},
        'deposit_note': {'key': 'depositNote', 'type': 'str'},
        'deposit_amount': {'key': 'depositAmount', 'type': 'float'},
        'memo': {'key': 'memo', 'type': 'str'},
        'service_start': {'key': 'serviceStart', 'type': 'iso-8601'},
        'service_end': {'key': 'serviceEnd', 'type': 'iso-8601'},
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'account_description': {'key': 'accountDescription', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AccountEdit, self).__init__(**kwargs)
        self.account_code = kwargs.get('account_code', None)
        self.account_info = kwargs.get('account_info', None)
        self.cost_center_id = kwargs.get('cost_center_id', None)
        self.customer_id = kwargs.get('customer_id', None)
        self.contact_id = kwargs.get('contact_id', None)
        self.active = kwargs.get('active', None)
        self.accrual_enabled = kwargs.get('accrual_enabled', None)
        self.postal_code = kwargs.get('postal_code', None)
        self.city = kwargs.get('city', None)
        self.state = kwargs.get('state', None)
        self.country = kwargs.get('country', None)
        self.line1 = kwargs.get('line1', None)
        self.line2 = kwargs.get('line2', None)
        self.line3 = kwargs.get('line3', "Æ")
        self.deposit_paid = kwargs.get('deposit_paid', None)
        self.deposit_return = kwargs.get('deposit_return', None)
        self.deposit_note = kwargs.get('deposit_note', None)
        self.deposit_amount = kwargs.get('deposit_amount', None)
        self.memo = kwargs.get('memo', None)
        self.service_start = kwargs.get('service_start', None)
        self.service_end = kwargs.get('service_end', None)
        self.general_ledger_id = kwargs.get('general_ledger_id', None)
        self.account_description = kwargs.get('account_description', "Æ")



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class VendorDigestActualYearlyResponse(Model):
    """VendorDigestActualYearlyResponse.

    :param vendor_code: The vendor code
    :type vendor_code: str
    :param vendor_info: The vendor info
    :type vendor_info: str
    :param vendor_id: The vendor identifier
    :type vendor_id: int
    :param global_use_unit:
    :type global_use_unit: ~energycap.sdk.models.UnitChild
    :param cost_unit:
    :type cost_unit: ~energycap.sdk.models.UnitChild
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param results: An array of yearly data
    :type results:
     list[~energycap.sdk.models.VendorDigestActualYearlyResponseResults]
    :param commodities: An array of yearly data per commodity
    :type commodities:
     list[~energycap.sdk.models.VendorDigestActualYearlyResponseCommodityData]
    """

    _attribute_map = {
        'vendor_code': {'key': 'vendorCode', 'type': 'str'},
        'vendor_info': {'key': 'vendorInfo', 'type': 'str'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'global_use_unit': {'key': 'globalUseUnit', 'type': 'UnitChild'},
        'cost_unit': {'key': 'costUnit', 'type': 'UnitChild'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'results': {'key': 'results', 'type': '[VendorDigestActualYearlyResponseResults]'},
        'commodities': {'key': 'commodities', 'type': '[VendorDigestActualYearlyResponseCommodityData]'},
    }

    def __init__(self, *, vendor_code: str=None, vendor_info: str=None, vendor_id: int=None, global_use_unit=None, cost_unit=None, updated=None, results=None, commodities=None, **kwargs) -> None:
        super(VendorDigestActualYearlyResponse, self).__init__(**kwargs)
        self.vendor_code = vendor_code
        self.vendor_info = vendor_info
        self.vendor_id = vendor_id
        self.global_use_unit = global_use_unit
        self.cost_unit = cost_unit
        self.updated = updated
        self.results = results
        self.commodities = commodities



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountAlertResponse(Model):
    """AccountAlertResponse.

    :param alert_id:
    :type alert_id: int
    :param begin_date:
    :type begin_date: datetime
    :param end_date:
    :type end_date: datetime
    :param message:
    :type message: str
    :param allow_bill_processing:
    :type allow_bill_processing: bool
    """

    _attribute_map = {
        'alert_id': {'key': 'alertId', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'message': {'key': 'message', 'type': 'str'},
        'allow_bill_processing': {'key': 'allowBillProcessing', 'type': 'bool'},
    }

    def __init__(self, *, alert_id: int=None, begin_date=None, end_date=None, message: str=None, allow_bill_processing: bool=None, **kwargs) -> None:
        super(AccountAlertResponse, self).__init__(**kwargs)
        self.alert_id = alert_id
        self.begin_date = begin_date
        self.end_date = end_date
        self.message = message
        self.allow_bill_processing = allow_bill_processing



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillHistoryResponse(Model):
    """BillHistoryResponse.

    :param bill_id: The bill's bill id
    :type bill_id: int
    :param billing_period: The bill's billing period
    :type billing_period: int
    :param begin_date: The bill's begin date
    :type begin_date: datetime
    :param end_date: The bill's end date
    :type end_date: datetime
    :param created_date: The bill's created date
    :type created_date: datetime
    :param total_cost: The bill's total cost
    :type total_cost: float
    :param total_cost_unit:
    :type total_cost_unit: ~energycap.sdk.models.UnitChild
    :param void: The bill's void indicator
    :type void: bool
    :param accrual: The bill's accrual indicator
    :type accrual: bool
    :param invoice_number: The bill's invoice number
    :type invoice_number: str
    :param estimated: Indicates if the bill is estimated or not
    :type estimated: bool
    :param due_date: The bill's due date
    :type due_date: datetime
    :param statement_date: The bill's statement date
    :type statement_date: datetime
    :param bill_account_meters: The bill's account-meter summaries
    :type bill_account_meters:
     list[~energycap.sdk.models.BillAccountMeterChild]
    """

    _attribute_map = {
        'bill_id': {'key': 'billId', 'type': 'int'},
        'billing_period': {'key': 'billingPeriod', 'type': 'int'},
        'begin_date': {'key': 'beginDate', 'type': 'iso-8601'},
        'end_date': {'key': 'endDate', 'type': 'iso-8601'},
        'created_date': {'key': 'createdDate', 'type': 'iso-8601'},
        'total_cost': {'key': 'totalCost', 'type': 'float'},
        'total_cost_unit': {'key': 'totalCostUnit', 'type': 'UnitChild'},
        'void': {'key': 'void', 'type': 'bool'},
        'accrual': {'key': 'accrual', 'type': 'bool'},
        'invoice_number': {'key': 'invoiceNumber', 'type': 'str'},
        'estimated': {'key': 'estimated', 'type': 'bool'},
        'due_date': {'key': 'dueDate', 'type': 'iso-8601'},
        'statement_date': {'key': 'statementDate', 'type': 'iso-8601'},
        'bill_account_meters': {'key': 'billAccountMeters', 'type': '[BillAccountMeterChild]'},
    }

    def __init__(self, **kwargs):
        super(BillHistoryResponse, self).__init__(**kwargs)
        self.bill_id = kwargs.get('bill_id', None)
        self.billing_period = kwargs.get('billing_period', None)
        self.begin_date = kwargs.get('begin_date', None)
        self.end_date = kwargs.get('end_date', None)
        self.created_date = kwargs.get('created_date', None)
        self.total_cost = kwargs.get('total_cost', None)
        self.total_cost_unit = kwargs.get('total_cost_unit', None)
        self.void = kwargs.get('void', None)
        self.accrual = kwargs.get('accrual', None)
        self.invoice_number = kwargs.get('invoice_number', None)
        self.estimated = kwargs.get('estimated', None)
        self.due_date = kwargs.get('due_date', None)
        self.statement_date = kwargs.get('statement_date', None)
        self.bill_account_meters = kwargs.get('bill_account_meters', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ListResponse(Model):
    """ListResponse.

    :param list_id: Specific List Identifier
    :type list_id: int
    :param data: Data for the bill list
    :type data: list[list[~energycap.sdk.models.ListResponseListItem]]
    :param field: Definition of the bill list - available filters and columns
    :type field: list[~energycap.sdk.models.ListResponseListField]
    :param meta: Meta data about the list
     Can contain:
     TotalCount - Total number of items that match the filter
     TotalCost - Total Cost of all the items that match the filter
     costUnitInfo - The currency unit
     ErrorMessage - Indicates data fetch error.
    :type meta: dict[str, object]
    """

    _attribute_map = {
        'list_id': {'key': 'listId', 'type': 'int'},
        'data': {'key': 'data', 'type': '[[ListResponseListItem]]'},
        'field': {'key': 'field', 'type': '[ListResponseListField]'},
        'meta': {'key': 'meta', 'type': '{object}'},
    }

    def __init__(self, *, list_id: int=None, data=None, field=None, meta=None, **kwargs) -> None:
        super(ListResponse, self).__init__(**kwargs)
        self.list_id = list_id
        self.data = data
        self.field = field
        self.meta = meta



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class NotificationSettingRequest(Model):
    """NotificationSettingRequest.

    All required parameters must be populated in order to send to Azure.

    :param notification_type_id: Required. The id of the notification type
     <span class='property-internal'>Required</span>
    :type notification_type_id: int
    :param configured_notification_option: Required. Update the configured
     notification option
     To get the list of available options for each setting call the
     GetNotificationSystemSettings or GetNotificationUserSettings API
     If your database is not configured to send emails, passing in
     ShowInAppAndSendEmail will return an error <span
     class='property-internal'>One of ShowInAppAndSendEmail, ShowInAppOnly, Off
     </span> <span class='property-internal'>Required</span>
    :type configured_notification_option: str
    """

    _validation = {
        'notification_type_id': {'required': True},
        'configured_notification_option': {'required': True},
    }

    _attribute_map = {
        'notification_type_id': {'key': 'notificationTypeId', 'type': 'int'},
        'configured_notification_option': {'key': 'configuredNotificationOption', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(NotificationSettingRequest, self).__init__(**kwargs)
        self.notification_type_id = kwargs.get('notification_type_id', None)
        self.configured_notification_option = kwargs.get('configured_notification_option', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AuditSettingsResponse(Model):
    """AuditSettingsResponse.

    All required parameters must be populated in order to send to Azure.

    :param bill_contains_line_item_descriptions:
    :type bill_contains_line_item_descriptions:
     ~energycap.sdk.models.BillContainsLineItemDescriptionsSettingResponse
    :param bill_contains_line_item_types:
    :type bill_contains_line_item_types:
     ~energycap.sdk.models.BillContainsLineItemTypesSettingResponse
    :param total_bill_cost_does_not_match_line_item_types:
    :type total_bill_cost_does_not_match_line_item_types:
     ~energycap.sdk.models.TotalBillCostDoesNotMatchLineItemTypesSettingResponse
    :param billing_period_outside_start_end_dates:
    :type billing_period_outside_start_end_dates:
     ~energycap.sdk.models.AuditSettingResponse
    :param bill_overlaps_with_other_account_bill:
    :type bill_overlaps_with_other_account_bill:
     ~energycap.sdk.models.AuditSettingResponse
    :param gap_between_bill_and_previous_bill_on_account:
    :type gap_between_bill_and_previous_bill_on_account:
     ~energycap.sdk.models.AuditSettingResponse
    :param bill_ends_in_future:
    :type bill_ends_in_future: ~energycap.sdk.models.AuditSettingResponse
    :param account_has_multiple_bills_in_billing_period:
    :type account_has_multiple_bills_in_billing_period:
     ~energycap.sdk.models.AuditSettingResponse
    :param statement_date_before_end_date:
    :type statement_date_before_end_date:
     ~energycap.sdk.models.AuditSettingResponse
    :param due_date_before_end_date:
    :type due_date_before_end_date: ~energycap.sdk.models.AuditSettingResponse
    :param bill_significantly_shorter_or_longer_than_previous:
    :type bill_significantly_shorter_or_longer_than_previous:
     ~energycap.sdk.models.BillSignificantlyShorterOrLongerThanPreviousSettingResponse
    :param too_many_consecutive_estimated_bills:
    :type too_many_consecutive_estimated_bills:
     ~energycap.sdk.models.TooManyConsecutiveEstimatedBillsSettingResponse
    :param due_date_too_long_after_bill_end: Required.
    :type due_date_too_long_after_bill_end:
     ~energycap.sdk.models.DueDateTooLongAfterBillEndSettingResponse
    :param statement_date_too_long_after_bill_end: Required.
    :type statement_date_too_long_after_bill_end:
     ~energycap.sdk.models.StatementDateTooLongAfterBillEndSettingResponse
    :param invoice_number_is_repeated_on_account:
    :type invoice_number_is_repeated_on_account:
     ~energycap.sdk.models.AuditSettingResponse
    :param likely_duplicate_bill_on_account:
    :type likely_duplicate_bill_on_account:
     ~energycap.sdk.models.AuditSettingResponse
    :param total_meter_cost_is_percentage_higher_than_past_year:
    :type total_meter_cost_is_percentage_higher_than_past_year:
     ~energycap.sdk.models.AuditSettingResponse
    :param total_meter_use_is_percentage_higher_than_past_year:
    :type total_meter_use_is_percentage_higher_than_past_year:
     ~energycap.sdk.models.AuditSettingResponse
    :param serial_number_does_not_match_import_file:
    :type serial_number_does_not_match_import_file:
     ~energycap.sdk.models.AuditSettingResponse
    :param rate_code_does_not_match_import_file:
    :type rate_code_does_not_match_import_file:
     ~energycap.sdk.models.AuditSettingResponse
    :param import_file_start_date_adjusted_to_prevent_gaps:
    :type import_file_start_date_adjusted_to_prevent_gaps:
     ~energycap.sdk.models.AuditSettingResponse
    :param account_alert_exists_on_account_in_import_file:
    :type account_alert_exists_on_account_in_import_file:
     ~energycap.sdk.models.AuditSettingResponse
    :param abnormal_bill_cost_with_outlier_analysis:
    :type abnormal_bill_cost_with_outlier_analysis:
     ~energycap.sdk.models.AbnormalBillCostWithOutlierAnalysisSettingResponse
    :param abnormal_bill_use_with_outlier_analysis: Required.
    :type abnormal_bill_use_with_outlier_analysis:
     ~energycap.sdk.models.AbnormalBillUseWithOutlierAnalysisSettingResponse
    :param abnormal_bill_demand_with_outlier_analysis: Required.
    :type abnormal_bill_demand_with_outlier_analysis:
     ~energycap.sdk.models.AbnormalBillDemandWithOutlierAnalysisSettingResponse
    """

    _validation = {
        'due_date_too_long_after_bill_end': {'required': True},
        'statement_date_too_long_after_bill_end': {'required': True},
        'abnormal_bill_use_with_outlier_analysis': {'required': True},
        'abnormal_bill_demand_with_outlier_analysis': {'required': True},
    }

    _attribute_map = {
        'bill_contains_line_item_descriptions': {'key': 'billContainsLineItemDescriptions', 'type': 'BillContainsLineItemDescriptionsSettingResponse'},
        'bill_contains_line_item_types': {'key': 'billContainsLineItemTypes', 'type': 'BillContainsLineItemTypesSettingResponse'},
        'total_bill_cost_does_not_match_line_item_types': {'key': 'totalBillCostDoesNotMatchLineItemTypes', 'type': 'TotalBillCostDoesNotMatchLineItemTypesSettingResponse'},
        'billing_period_outside_start_end_dates': {'key': 'billingPeriodOutsideStartEndDates', 'type': 'AuditSettingResponse'},
        'bill_overlaps_with_other_account_bill': {'key': 'billOverlapsWithOtherAccountBill', 'type': 'AuditSettingResponse'},
        'gap_between_bill_and_previous_bill_on_account': {'key': 'gapBetweenBillAndPreviousBillOnAccount', 'type': 'AuditSettingResponse'},
        'bill_ends_in_future': {'key': 'billEndsInFuture', 'type': 'AuditSettingResponse'},
        'account_has_multiple_bills_in_billing_period': {'key': 'accountHasMultipleBillsInBillingPeriod', 'type': 'AuditSettingResponse'},
        'statement_date_before_end_date': {'key': 'statementDateBeforeEndDate', 'type': 'AuditSettingResponse'},
        'due_date_before_end_date': {'key': 'dueDateBeforeEndDate', 'type': 'AuditSettingResponse'},
        'bill_significantly_shorter_or_longer_than_previous': {'key': 'billSignificantlyShorterOrLongerThanPrevious', 'type': 'BillSignificantlyShorterOrLongerThanPreviousSettingResponse'},
        'too_many_consecutive_estimated_bills': {'key': 'tooManyConsecutiveEstimatedBills', 'type': 'TooManyConsecutiveEstimatedBillsSettingResponse'},
        'due_date_too_long_after_bill_end': {'key': 'dueDateTooLongAfterBillEnd', 'type': 'DueDateTooLongAfterBillEndSettingResponse'},
        'statement_date_too_long_after_bill_end': {'key': 'statementDateTooLongAfterBillEnd', 'type': 'StatementDateTooLongAfterBillEndSettingResponse'},
        'invoice_number_is_repeated_on_account': {'key': 'invoiceNumberIsRepeatedOnAccount', 'type': 'AuditSettingResponse'},
        'likely_duplicate_bill_on_account': {'key': 'likelyDuplicateBillOnAccount', 'type': 'AuditSettingResponse'},
        'total_meter_cost_is_percentage_higher_than_past_year': {'key': 'totalMeterCostIsPercentageHigherThanPastYear', 'type': 'AuditSettingResponse'},
        'total_meter_use_is_percentage_higher_than_past_year': {'key': 'totalMeterUseIsPercentageHigherThanPastYear', 'type': 'AuditSettingResponse'},
        'serial_number_does_not_match_import_file': {'key': 'serialNumberDoesNotMatchImportFile', 'type': 'AuditSettingResponse'},
        'rate_code_does_not_match_import_file': {'key': 'rateCodeDoesNotMatchImportFile', 'type': 'AuditSettingResponse'},
        'import_file_start_date_adjusted_to_prevent_gaps': {'key': 'importFileStartDateAdjustedToPreventGaps', 'type': 'AuditSettingResponse'},
        'account_alert_exists_on_account_in_import_file': {'key': 'accountAlertExistsOnAccountInImportFile', 'type': 'AuditSettingResponse'},
        'abnormal_bill_cost_with_outlier_analysis': {'key': 'abnormalBillCostWithOutlierAnalysis', 'type': 'AbnormalBillCostWithOutlierAnalysisSettingResponse'},
        'abnormal_bill_use_with_outlier_analysis': {'key': 'abnormalBillUseWithOutlierAnalysis', 'type': 'AbnormalBillUseWithOutlierAnalysisSettingResponse'},
        'abnormal_bill_demand_with_outlier_analysis': {'key': 'abnormalBillDemandWithOutlierAnalysis', 'type': 'AbnormalBillDemandWithOutlierAnalysisSettingResponse'},
    }

    def __init__(self, **kwargs):
        super(AuditSettingsResponse, self).__init__(**kwargs)
        self.bill_contains_line_item_descriptions = kwargs.get('bill_contains_line_item_descriptions', None)
        self.bill_contains_line_item_types = kwargs.get('bill_contains_line_item_types', None)
        self.total_bill_cost_does_not_match_line_item_types = kwargs.get('total_bill_cost_does_not_match_line_item_types', None)
        self.billing_period_outside_start_end_dates = kwargs.get('billing_period_outside_start_end_dates', None)
        self.bill_overlaps_with_other_account_bill = kwargs.get('bill_overlaps_with_other_account_bill', None)
        self.gap_between_bill_and_previous_bill_on_account = kwargs.get('gap_between_bill_and_previous_bill_on_account', None)
        self.bill_ends_in_future = kwargs.get('bill_ends_in_future', None)
        self.account_has_multiple_bills_in_billing_period = kwargs.get('account_has_multiple_bills_in_billing_period', None)
        self.statement_date_before_end_date = kwargs.get('statement_date_before_end_date', None)
        self.due_date_before_end_date = kwargs.get('due_date_before_end_date', None)
        self.bill_significantly_shorter_or_longer_than_previous = kwargs.get('bill_significantly_shorter_or_longer_than_previous', None)
        self.too_many_consecutive_estimated_bills = kwargs.get('too_many_consecutive_estimated_bills', None)
        self.due_date_too_long_after_bill_end = kwargs.get('due_date_too_long_after_bill_end', None)
        self.statement_date_too_long_after_bill_end = kwargs.get('statement_date_too_long_after_bill_end', None)
        self.invoice_number_is_repeated_on_account = kwargs.get('invoice_number_is_repeated_on_account', None)
        self.likely_duplicate_bill_on_account = kwargs.get('likely_duplicate_bill_on_account', None)
        self.total_meter_cost_is_percentage_higher_than_past_year = kwargs.get('total_meter_cost_is_percentage_higher_than_past_year', None)
        self.total_meter_use_is_percentage_higher_than_past_year = kwargs.get('total_meter_use_is_percentage_higher_than_past_year', None)
        self.serial_number_does_not_match_import_file = kwargs.get('serial_number_does_not_match_import_file', None)
        self.rate_code_does_not_match_import_file = kwargs.get('rate_code_does_not_match_import_file', None)
        self.import_file_start_date_adjusted_to_prevent_gaps = kwargs.get('import_file_start_date_adjusted_to_prevent_gaps', None)
        self.account_alert_exists_on_account_in_import_file = kwargs.get('account_alert_exists_on_account_in_import_file', None)
        self.abnormal_bill_cost_with_outlier_analysis = kwargs.get('abnormal_bill_cost_with_outlier_analysis', None)
        self.abnormal_bill_use_with_outlier_analysis = kwargs.get('abnormal_bill_use_with_outlier_analysis', None)
        self.abnormal_bill_demand_with_outlier_analysis = kwargs.get('abnormal_bill_demand_with_outlier_analysis', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RateCreate(Model):
    """RateCreate.

    All required parameters must be populated in order to send to Azure.

    :param name: Required.  <span class='property-internal'>Required</span>
     <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type name: str
    :param vendor_id: Required.  <span
     class='property-internal'>Required</span>
    :type vendor_id: int
    :param commodity_id: Required.  <span
     class='property-internal'>Required</span>
    :type commodity_id: int
    :param note:  <span class='property-internal'>Must be between 0 and 255
     characters</span>
    :type note: str
    """

    _validation = {
        'name': {'required': True, 'max_length': 255, 'min_length': 0},
        'vendor_id': {'required': True},
        'commodity_id': {'required': True},
        'note': {'max_length': 255, 'min_length': 0},
    }

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'vendor_id': {'key': 'vendorId', 'type': 'int'},
        'commodity_id': {'key': 'commodityId', 'type': 'int'},
        'note': {'key': 'note', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(RateCreate, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.vendor_id = kwargs.get('vendor_id', None)
        self.commodity_id = kwargs.get('commodity_id', None)
        self.note = kwargs.get('note', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CostCenterResponse(Model):
    """CostCenterResponse.

    :param cost_center_id: The cost center identifier
    :type cost_center_id: int
    :param cost_center_code: The cost center code
    :type cost_center_code: str
    :param cost_center_info: The cost center info
    :type cost_center_info: str
    :param parent:
    :type parent: ~energycap.sdk.models.CostCenterChild
    :param cost_centers: An array of child cost centers
    :type cost_centers: list[~energycap.sdk.models.CostCenterChild]
    :param accounts: An array of child accounts
    :type accounts: list[~energycap.sdk.models.CostCenterAccountChild]
    """

    _attribute_map = {
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'cost_center_code': {'key': 'costCenterCode', 'type': 'str'},
        'cost_center_info': {'key': 'costCenterInfo', 'type': 'str'},
        'parent': {'key': 'parent', 'type': 'CostCenterChild'},
        'cost_centers': {'key': 'costCenters', 'type': '[CostCenterChild]'},
        'accounts': {'key': 'accounts', 'type': '[CostCenterAccountChild]'},
    }

    def __init__(self, *, cost_center_id: int=None, cost_center_code: str=None, cost_center_info: str=None, parent=None, cost_centers=None, accounts=None, **kwargs) -> None:
        super(CostCenterResponse, self).__init__(**kwargs)
        self.cost_center_id = cost_center_id
        self.cost_center_code = cost_center_code
        self.cost_center_info = cost_center_info
        self.parent = parent
        self.cost_centers = cost_centers
        self.accounts = accounts



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BenchmarkValueRequest(Model):
    """BenchmarkValueRequest.

    All required parameters must be populated in order to send to Azure.

    :param effective_date: Required. The effective date for the benchmark
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Required</span>
    :type effective_date: datetime
    :param value: Required. The benchmark value <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     scale of 6</span> <span class='property-internal'>Must be between 0 and
     1.7976931348623157E+308</span> <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     scale of 6</span> <span class='property-internal'>Must be between 0 and
     1.7976931348623157E+308</span>
    :type value: float
    """

    _validation = {
        'effective_date': {'required': True},
        'value': {'required': True, 'minimum': 0},
    }

    _attribute_map = {
        'effective_date': {'key': 'effectiveDate', 'type': 'iso-8601'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(BenchmarkValueRequest, self).__init__(**kwargs)
        self.effective_date = kwargs.get('effective_date', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CopyMeterRequest(Model):
    """Defines a meter whose use or cost will be copied when calculating a bill
    The meter may have a commodity which is different than the destination
    meter
    When doing the calculation we will sum the use or cost across all accounts
    this meter is associated with for the billing period begin run.

    All required parameters must be populated in order to send to Azure.

    :param meter_id: Required. Meter from which use or cost will be copied
     <span class='property-internal'>Required</span> <span
     class='property-internal'>Topmost (LogicalDevice)</span>
    :type meter_id: int
    :param percentage: Required. Percentage of use or cost to copy
     Pass the percentage value
     For example 50.5% should be 50.5 <span
     class='property-internal'>Required</span> <span class='property-info'>Max
     scale of 8</span>
    :type percentage: float
    """

    _validation = {
        'meter_id': {'required': True},
        'percentage': {'required': True},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'percentage': {'key': 'percentage', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(CopyMeterRequest, self).__init__(**kwargs)
        self.meter_id = kwargs.get('meter_id', None)
        self.percentage = kwargs.get('percentage', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class TaskEdit(Model):
    """TaskEdit.

    All required parameters must be populated in order to send to Azure.

    :param task_note: Required.  <span
     class='property-internal'>Required</span>
    :type task_note: str
    """

    _validation = {
        'task_note': {'required': True},
    }

    _attribute_map = {
        'task_note': {'key': 'taskNote', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(TaskEdit, self).__init__(**kwargs)
        self.task_note = kwargs.get('task_note', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SubmissionTypeResponse(Model):
    """SubmissionTypeResponse.

    :param submission_type_id: The identifier for the submission type
    :type submission_type_id: int
    :param submission_type_name: The name of the submission type
    :type submission_type_name: str
    """

    _attribute_map = {
        'submission_type_id': {'key': 'submissionTypeId', 'type': 'int'},
        'submission_type_name': {'key': 'submissionTypeName', 'type': 'str'},
    }

    def __init__(self, *, submission_type_id: int=None, submission_type_name: str=None, **kwargs) -> None:
        super(SubmissionTypeResponse, self).__init__(**kwargs)
        self.submission_type_id = submission_type_id
        self.submission_type_name = submission_type_name



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Me(Model):
    """Me.

    :param place:
    :type place: ~energycap.sdk.models.TopmostPlace
    :param cost_center:
    :type cost_center: ~energycap.sdk.models.TopmostCostCenter
    :param token: User's authentication token
    :type token: str
    :param external_user_id: User's external user ID
    :type external_user_id: str
    :param system_user_code: Username
    :type system_user_code: str
    :param system_user_id: Unique identifier for the user
    :type system_user_id: int
    :param full_name: User's full name
    :type full_name: str
    :param email: User's email address
    :type email: str
    :param number_of_accounting_periods: Number of accounting periods
     configured for the user's owner
    :type number_of_accounting_periods: int
    :param calendarization_method: Calendarization configured for user's owner
    :type calendarization_method: str
    :param fiscal_year_start_month: Fiscal year start month configured for the
     user's owner
    :type fiscal_year_start_month: int
    :param fiscal_year_method: Method configured for identification of fiscal
     year for the user's owner
    :type fiscal_year_method: str
    :param claim: List of the user's claims
    :type claim: list[~energycap.sdk.models.Claim]
    :param preference:
    :type preference: ~energycap.sdk.models.Preference
    :param date_formats: Available date formats
    :type date_formats: list[str]
    :param time_formats: Available time formats
    :type time_formats: list[~energycap.sdk.models.TimeFormatResponse]
    :param currency_unit:
    :type currency_unit: ~energycap.sdk.models.UnitChild
    :param current_accounting_period: Current account period calculated from
     configuration for the user's owner
    :type current_accounting_period: int
    :param user_role_name: User's user role
    :type user_role_name: str
    :param permissions:
    :type permissions: ~energycap.sdk.models.Permissions
    :param feature_flags: List of enabled feature flags
    :type feature_flags: list[str]
    :param upgrade_version_v3: Upgrade version number (Version 3)
    :type upgrade_version_v3: str
    :param upgrade_version_v7: Upgrade version number (Version 7)
    :type upgrade_version_v7: str
    :param sku: Application SKU as set in the license code
    :type sku: str
    :param environment: Current environment
    :type environment: str
    :param build_date: Build date for the current application version
    :type build_date: datetime
    :param report_distribution_from_email_address: The email address to use as
     the sender for report distribution
    :type report_distribution_from_email_address: str
    :param report_distribution_from_email_name: The email name to use as the
     sender for report distribution
    :type report_distribution_from_email_name: str
    :param application_mode: The current mode of the application
     Values: Online, Offline
    :type application_mode: str
    :param current_database_version: The current version of the database
    :type current_database_version: int
    :param utility_platform_settings:
    :type utility_platform_settings: ~energycap.sdk.models.UtilityPlatform
    :param unplaced_meters_parent_id: Node where unplaced meters are assigned
    :type unplaced_meters_parent_id: int
    :param unplaced_accounts_parent_id: Node where unplaced accounts are
     assigned
    :type unplaced_accounts_parent_id: int
    """

    _attribute_map = {
        'place': {'key': 'place', 'type': 'TopmostPlace'},
        'cost_center': {'key': 'costCenter', 'type': 'TopmostCostCenter'},
        'token': {'key': 'token', 'type': 'str'},
        'external_user_id': {'key': 'externalUserId', 'type': 'str'},
        'system_user_code': {'key': 'systemUserCode', 'type': 'str'},
        'system_user_id': {'key': 'systemUserId', 'type': 'int'},
        'full_name': {'key': 'fullName', 'type': 'str'},
        'email': {'key': 'email', 'type': 'str'},
        'number_of_accounting_periods': {'key': 'numberOfAccountingPeriods', 'type': 'int'},
        'calendarization_method': {'key': 'calendarizationMethod', 'type': 'str'},
        'fiscal_year_start_month': {'key': 'fiscalYearStartMonth', 'type': 'int'},
        'fiscal_year_method': {'key': 'fiscalYearMethod', 'type': 'str'},
        'claim': {'key': 'claim', 'type': '[Claim]'},
        'preference': {'key': 'preference', 'type': 'Preference'},
        'date_formats': {'key': 'dateFormats', 'type': '[str]'},
        'time_formats': {'key': 'timeFormats', 'type': '[TimeFormatResponse]'},
        'currency_unit': {'key': 'currencyUnit', 'type': 'UnitChild'},
        'current_accounting_period': {'key': 'currentAccountingPeriod', 'type': 'int'},
        'user_role_name': {'key': 'userRoleName', 'type': 'str'},
        'permissions': {'key': 'permissions', 'type': 'Permissions'},
        'feature_flags': {'key': 'featureFlags', 'type': '[str]'},
        'upgrade_version_v3': {'key': 'upgradeVersion_V3', 'type': 'str'},
        'upgrade_version_v7': {'key': 'upgradeVersion_V7', 'type': 'str'},
        'sku': {'key': 'sku', 'type': 'str'},
        'environment': {'key': 'environment', 'type': 'str'},
        'build_date': {'key': 'buildDate', 'type': 'iso-8601'},
        'report_distribution_from_email_address': {'key': 'reportDistributionFromEmailAddress', 'type': 'str'},
        'report_distribution_from_email_name': {'key': 'reportDistributionFromEmailName', 'type': 'str'},
        'application_mode': {'key': 'applicationMode', 'type': 'str'},
        'current_database_version': {'key': 'currentDatabaseVersion', 'type': 'int'},
        'utility_platform_settings': {'key': 'utilityPlatformSettings', 'type': 'UtilityPlatform'},
        'unplaced_meters_parent_id': {'key': 'unplacedMetersParentId', 'type': 'int'},
        'unplaced_accounts_parent_id': {'key': 'unplacedAccountsParentId', 'type': 'int'},
    }

    def __init__(self, *, place=None, cost_center=None, token: str=None, external_user_id: str=None, system_user_code: str=None, system_user_id: int=None, full_name: str=None, email: str=None, number_of_accounting_periods: int=None, calendarization_method: str=None, fiscal_year_start_month: int=None, fiscal_year_method: str=None, claim=None, preference=None, date_formats=None, time_formats=None, currency_unit=None, current_accounting_period: int=None, user_role_name: str=None, permissions=None, feature_flags=None, upgrade_version_v3: str=None, upgrade_version_v7: str=None, sku: str=None, environment: str=None, build_date=None, report_distribution_from_email_address: str=None, report_distribution_from_email_name: str=None, application_mode: str=None, current_database_version: int=None, utility_platform_settings=None, unplaced_meters_parent_id: int=None, unplaced_accounts_parent_id: int=None, **kwargs) -> None:
        super(Me, self).__init__(**kwargs)
        self.place = place
        self.cost_center = cost_center
        self.token = token
        self.external_user_id = external_user_id
        self.system_user_code = system_user_code
        self.system_user_id = system_user_id
        self.full_name = full_name
        self.email = email
        self.number_of_accounting_periods = number_of_accounting_periods
        self.calendarization_method = calendarization_method
        self.fiscal_year_start_month = fiscal_year_start_month
        self.fiscal_year_method = fiscal_year_method
        self.claim = claim
        self.preference = preference
        self.date_formats = date_formats
        self.time_formats = time_formats
        self.currency_unit = currency_unit
        self.current_accounting_period = current_accounting_period
        self.user_role_name = user_role_name
        self.permissions = permissions
        self.feature_flags = feature_flags
        self.upgrade_version_v3 = upgrade_version_v3
        self.upgrade_version_v7 = upgrade_version_v7
        self.sku = sku
        self.environment = environment
        self.build_date = build_date
        self.report_distribution_from_email_address = report_distribution_from_email_address
        self.report_distribution_from_email_name = report_distribution_from_email_name
        self.application_mode = application_mode
        self.current_database_version = current_database_version
        self.utility_platform_settings = utility_platform_settings
        self.unplaced_meters_parent_id = unplaced_meters_parent_id
        self.unplaced_accounts_parent_id = unplaced_accounts_parent_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class ReadingResponse(Model):
    """ReadingResponse.

    :param imported_readings_count: The number of successfully imported
     readings
    :type imported_readings_count: int
    :param failed_readings_count: The number of failed reading imports
    :type failed_readings_count: int
    :param failed_readings: Data representing the failed reading imports
    :type failed_readings: list[~energycap.sdk.models.FailedReadingResponse]
    """

    _attribute_map = {
        'imported_readings_count': {'key': 'importedReadingsCount', 'type': 'int'},
        'failed_readings_count': {'key': 'failedReadingsCount', 'type': 'int'},
        'failed_readings': {'key': 'failedReadings', 'type': '[FailedReadingResponse]'},
    }

    def __init__(self, *, imported_readings_count: int=None, failed_readings_count: int=None, failed_readings=None, **kwargs) -> None:
        super(ReadingResponse, self).__init__(**kwargs)
        self.imported_readings_count = imported_readings_count
        self.failed_readings_count = failed_readings_count
        self.failed_readings = failed_readings



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AccountTypeChild(Model):
    """AccountTypeChild.

    :param account_type_id: The account type identifier
    :type account_type_id: int
    :param account_type_code: The account type code
    :type account_type_code: str
    :param account_type_info: The account type info
    :type account_type_info: str
    """

    _attribute_map = {
        'account_type_id': {'key': 'accountTypeId', 'type': 'int'},
        'account_type_code': {'key': 'accountTypeCode', 'type': 'str'},
        'account_type_info': {'key': 'accountTypeInfo', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AccountTypeChild, self).__init__(**kwargs)
        self.account_type_id = kwargs.get('account_type_id', None)
        self.account_type_code = kwargs.get('account_type_code', None)
        self.account_type_info = kwargs.get('account_type_info', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchCostCenterChildSearchCostCenter(Model):
    """SearchCostCenterChildSearchCostCenter.

    All required parameters must be populated in order to send to Azure.

    :param cost_center_id: The cost center identifier
    :type cost_center_id: int
    :param cost_center_code: Required. The cost center code <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 32 characters</span>
    :type cost_center_code: str
    :param cost_center_info: Required. The cost center info <span
     class='property-internal'>Required</span> <span
     class='property-internal'>Must be between 0 and 50 characters</span>
    :type cost_center_info: str
    :param parent_path: The collection of cost centers representing the path
     to its parent
    :type parent_path: list[~energycap.sdk.models.CostCenterChild]
    """

    _validation = {
        'cost_center_code': {'required': True, 'max_length': 32, 'min_length': 0},
        'cost_center_info': {'required': True, 'max_length': 50, 'min_length': 0},
    }

    _attribute_map = {
        'cost_center_id': {'key': 'costCenterId', 'type': 'int'},
        'cost_center_code': {'key': 'costCenterCode', 'type': 'str'},
        'cost_center_info': {'key': 'costCenterInfo', 'type': 'str'},
        'parent_path': {'key': 'parentPath', 'type': '[CostCenterChild]'},
    }

    def __init__(self, *, cost_center_code: str, cost_center_info: str, cost_center_id: int=None, parent_path=None, **kwargs) -> None:
        super(SearchCostCenterChildSearchCostCenter, self).__init__(**kwargs)
        self.cost_center_id = cost_center_id
        self.cost_center_code = cost_center_code
        self.cost_center_info = cost_center_info
        self.parent_path = parent_path



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarMeterLinkRequest(Model):
    """EnergyStarMeterLinkRequest.

    All required parameters must be populated in order to send to Azure.

    :param meter_id: Required. The meter identifier <span
     class='property-internal'>Required</span>
    :type meter_id: int
    :param pm_meter_id: The Portfolio Manager meter identifier.  Set to null
     to unlink meter. <span class='property-internal'>Required (defined)</span>
    :type pm_meter_id: long
    """

    _validation = {
        'meter_id': {'required': True},
    }

    _attribute_map = {
        'meter_id': {'key': 'meterId', 'type': 'int'},
        'pm_meter_id': {'key': 'pmMeterId', 'type': 'long'},
    }

    def __init__(self, *, meter_id: int, pm_meter_id: int=None, **kwargs) -> None:
        super(EnergyStarMeterLinkRequest, self).__init__(**kwargs)
        self.meter_id = meter_id
        self.pm_meter_id = pm_meter_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class BillingPeriodUseUnitChild(Model):
    """BillingPeriodUseUnitChild.

    :param use: The total common use.
    :type use: float
    :param unit:
    :type unit: ~energycap.sdk.models.UnitChild
    """

    _attribute_map = {
        'use': {'key': 'use', 'type': 'float'},
        'unit': {'key': 'unit', 'type': 'UnitChild'},
    }

    def __init__(self, *, use: float=None, unit=None, **kwargs) -> None:
        super(BillingPeriodUseUnitChild, self).__init__(**kwargs)
        self.use = use
        self.unit = unit



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CalendarizedSumRequest(Model):
    """CalendarizedSumRequest.

    All required parameters must be populated in order to send to Azure.

    :param sum_meter_ids: Required. Meters in this list will have their use or
     cost added together during the bill calculation <span
     class='property-internal'>Cannot be Empty</span> <span
     class='property-internal'>Required</span>
    :type sum_meter_ids: list[int]
    """

    _validation = {
        'sum_meter_ids': {'required': True},
    }

    _attribute_map = {
        'sum_meter_ids': {'key': 'sumMeterIds', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(CalendarizedSumRequest, self).__init__(**kwargs)
        self.sum_meter_ids = kwargs.get('sum_meter_ids', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OtherSavingsRequest(Model):
    """OtherSavingsRequest.

    All required parameters must be populated in order to send to Azure.

    :param frequency: Required. Other savings type
     Possible values are: one-time, continuous and recurring <span
     class='property-internal'>Required</span>
    :type frequency: str
    :param other_savings_category_id: Required. Other savings category
     identifier <span class='property-internal'>Required</span>
    :type other_savings_category_id: int
    :param description: Required. Description <span
     class='property-internal'>Required</span>
    :type description: str
    :param start_period: Required. Other savings start period <span
     class='property-internal'>Required</span>
    :type start_period: int
    :param end_period: Other savings end period <span
     class='property-internal'>Required when frequency is set to continuous, or
     recurring</span>
    :type end_period: int
    :param annual_cycle_start_month: Month in which the other savings should
     begin
     This should only be set when the other savings type is recurring <span
     class='property-internal'>Required when frequency is set to
     recurring</span>
    :type annual_cycle_start_month: int
    :param annual_cycle_end_month: Month in which the other savings should end
     This should only be set when the other savings type is recurring <span
     class='property-internal'>Required when frequency is set to
     recurring</span>
    :type annual_cycle_end_month: int
    :param value: Required. Amount saved <span
     class='property-internal'>Required</span>
    :type value: float
    """

    _validation = {
        'frequency': {'required': True},
        'other_savings_category_id': {'required': True},
        'description': {'required': True},
        'start_period': {'required': True},
        'value': {'required': True},
    }

    _attribute_map = {
        'frequency': {'key': 'frequency', 'type': 'str'},
        'other_savings_category_id': {'key': 'otherSavingsCategoryId', 'type': 'int'},
        'description': {'key': 'description', 'type': 'str'},
        'start_period': {'key': 'startPeriod', 'type': 'int'},
        'end_period': {'key': 'endPeriod', 'type': 'int'},
        'annual_cycle_start_month': {'key': 'annualCycleStartMonth', 'type': 'int'},
        'annual_cycle_end_month': {'key': 'annualCycleEndMonth', 'type': 'int'},
        'value': {'key': 'value', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(OtherSavingsRequest, self).__init__(**kwargs)
        self.frequency = kwargs.get('frequency', None)
        self.other_savings_category_id = kwargs.get('other_savings_category_id', None)
        self.description = kwargs.get('description', None)
        self.start_period = kwargs.get('start_period', None)
        self.end_period = kwargs.get('end_period', None)
        self.annual_cycle_start_month = kwargs.get('annual_cycle_start_month', None)
        self.annual_cycle_end_month = kwargs.get('annual_cycle_end_month', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteRequest(Model):
    """RouteRequest.

    All required parameters must be populated in order to send to Azure.

    :param route_info: Required. The route info <span
     class='property-internal'>Must be between 0 and 32 characters</span> <span
     class='property-internal'>Required</span>
    :type route_info: str
    :param route_code: The route code
     This property has been deprecated. Route code will be generated from the
     value in route info <span class='property-internal'>Must be between 0 and
     16 characters</span>
    :type route_code: str
    :param meter_ids: Required. The list of IDs for meters to be assigned to
     the route. The order in which the meter IDs appear will determine their
     order on the route.
     NOTE: if the same meter ID is passed in multiple times, the first
     occurrence of the meter ID will be used to determine the order on the
     route <span class='property-internal'>Required</span>
    :type meter_ids: list[int]
    """

    _validation = {
        'route_info': {'required': True, 'max_length': 32, 'min_length': 0},
        'route_code': {'max_length': 16, 'min_length': 0},
        'meter_ids': {'required': True},
    }

    _attribute_map = {
        'route_info': {'key': 'routeInfo', 'type': 'str'},
        'route_code': {'key': 'routeCode', 'type': 'str'},
        'meter_ids': {'key': 'meterIds', 'type': '[int]'},
    }

    def __init__(self, **kwargs):
        super(RouteRequest, self).__init__(**kwargs)
        self.route_info = kwargs.get('route_info', None)
        self.route_code = kwargs.get('route_code', None)
        self.meter_ids = kwargs.get('meter_ids', None)
